@@ -5,25 +5,25 @@
     SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include <QTest>
-#include <QSignalSpy>
 #include <QDir>
 #include <QMenu>
 #include <QMimeData>
+#include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTemporaryDir>
+#include <QTest>
 
+#include "jobuidelegatefactory.h"
 #include "kiotesthelper.h"
-
-#include <KIO/DropJob>
-#include <KIO/StatJob>
-#include <KIO/CopyJob>
-#include <KIO/DeleteJob>
+#include "mockcoredelegateextensions.h"
 #include <KConfigGroup>
 #include <KDesktopFile>
 #include <KFileItemListProperties>
+#include <KIO/CopyJob>
+#include <KIO/DeleteJob>
+#include <KIO/DropJob>
+#include <KIO/StatJob>
 #include <KJobUiDelegate>
-#include "mockcoredelegateextensions.h"
 
 Q_DECLARE_METATYPE(Qt::KeyboardModifiers)
 Q_DECLARE_METATYPE(Qt::DropAction)
@@ -38,17 +38,16 @@ void initLocale()
 Q_CONSTRUCTOR_FUNCTION(initLocale)
 #endif
 
-
 class JobSpy : public QObject
 {
     Q_OBJECT
 public:
-    JobSpy(KIO::Job *job)
-        : QObject(nullptr),
-          m_spy(job, &KJob::result),
-          m_error(0)
+    explicit JobSpy(KIO::Job *job)
+        : QObject(nullptr)
+        , m_spy(job, &KJob::result)
+        , m_error(0)
     {
-        connect(job, &KJob::result, this, [this](KJob * job) {
+        connect(job, &KJob::result, this, [this](KJob *job) {
             m_error = job->error();
         });
     }
@@ -82,13 +81,13 @@ private Q_SLOTS:
     void initTestCase()
     {
         QStandardPaths::setTestModeEnabled(true);
-        qputenv("KIOSLAVE_ENABLE_TESTMODE", "1"); // ensure the ioslaves call QStandardPaths::setTestModeEnabled too
+        qputenv("KIOSLAVE_ENABLE_TESTMODE", "1"); // ensure the KIO workers call QStandardPaths::setTestModeEnabled too
 
-        // To avoid a runtime dependency on klauncher
-        qputenv("KDE_FORK_SLAVES", "yes");
+        KIO::setDefaultJobUiDelegateFactoryV2(nullptr);
+        KIO::setDefaultJobUiDelegateExtension(nullptr);
 
-        const QString trashDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/Trash");
-        QDir(trashDir).removeRecursively();
+        m_trashDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/Trash");
+        QDir(m_trashDir).removeRecursively();
 
         QVERIFY(m_tempDir.isValid());
         QVERIFY(m_nonWritableTempDir.isValid());
@@ -98,12 +97,13 @@ private Q_SLOTS:
         m_srcFile = m_srcDir + "/srcfile";
         m_srcLink = m_srcDir + "/link";
 
-        qRegisterMetaType<KIO::CopyJob*>();
+        qRegisterMetaType<KIO::CopyJob *>();
     }
 
     void cleanupTestCase()
     {
-        QVERIFY(QFile(m_nonWritableTempDir.path()).setPermissions(QFile::ReadOwner | QFile::ReadUser | QFile::WriteOwner | QFile::WriteUser | QFile::ExeOwner | QFile::ExeUser));
+        QVERIFY(QFile(m_nonWritableTempDir.path())
+                    .setPermissions(QFile::ReadOwner | QFile::ReadUser | QFile::WriteOwner | QFile::WriteUser | QFile::ExeOwner | QFile::ExeUser));
     }
 
     // Before every test method, ensure the test file m_srcFile exists
@@ -147,7 +147,6 @@ private Q_SLOTS:
         QUrl destUrl = QUrl::fromLocalFile(desktopPath);
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
         QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
         // Then the application is run with the source file as argument
@@ -170,16 +169,12 @@ private Q_SLOTS:
         QTest::addColumn<int>("expectedError");
         QTest::addColumn<bool>("shouldSourceStillExist");
 
-        QTest::newRow("Ctrl") << Qt::KeyboardModifiers(Qt::ControlModifier) << Qt::CopyAction << m_srcFile << QString()
-                              << 0 << true;
-        QTest::newRow("Shift") << Qt::KeyboardModifiers(Qt::ShiftModifier) << Qt::MoveAction << m_srcFile << QString()
-                               << 0 << false;
-        QTest::newRow("Ctrl_Shift") << Qt::KeyboardModifiers(Qt::ControlModifier | Qt::ShiftModifier) << Qt::LinkAction << m_srcFile << QString()
-                                    << 0 << true;
-        QTest::newRow("DropOnItself") << Qt::KeyboardModifiers() << Qt::CopyAction << m_srcDir << m_srcDir
-                                      << int(KIO::ERR_DROP_ON_ITSELF) << true;
-        QTest::newRow("DropDirOnFile") << Qt::KeyboardModifiers(Qt::ControlModifier) << Qt::CopyAction << m_srcDir << m_srcFile
-                                       << int(KIO::ERR_ACCESS_DENIED) << true;
+        QTest::newRow("Ctrl") << Qt::KeyboardModifiers(Qt::ControlModifier) << Qt::CopyAction << m_srcFile << QString() << 0 << true;
+        QTest::newRow("Shift") << Qt::KeyboardModifiers(Qt::ShiftModifier) << Qt::MoveAction << m_srcFile << QString() << 0 << false;
+        QTest::newRow("Ctrl_Shift") << Qt::KeyboardModifiers(Qt::ControlModifier | Qt::ShiftModifier) << Qt::LinkAction << m_srcFile << QString() << 0 << true;
+        QTest::newRow("DropOnItself") << Qt::KeyboardModifiers() << Qt::CopyAction << m_srcDir << m_srcDir << int(KIO::ERR_DROP_ON_ITSELF) << true;
+        QTest::newRow("DropDirOnFile") << Qt::KeyboardModifiers(Qt::ControlModifier) << Qt::CopyAction << m_srcDir << m_srcFile << int(KIO::ERR_ACCESS_DENIED)
+                                       << true;
         QTest::newRow("NonWritableDest") << Qt::KeyboardModifiers() << Qt::CopyAction << m_srcFile << m_nonWritableTempDir.path()
                                          << int(KIO::ERR_WRITE_ACCESS_DENIED) << true;
     }
@@ -205,8 +200,6 @@ private Q_SLOTS:
         m_mimeData.setUrls(QList<QUrl>{QUrl::fromLocalFile(srcFile)});
         QDropEvent dropEvent(QPoint(10, 10), dropAction, &m_mimeData, Qt::LeftButton, modifiers);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo | KIO::NoPrivilegeExecution);
-        job->setUiDelegate(nullptr);
-        job->setUiDelegateExtension(nullptr);
         JobSpy jobSpy(job);
         QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QSignalSpy itemCreatedSpy(job, &KIO::DropJob::itemCreated);
@@ -287,20 +280,25 @@ private Q_SLOTS:
     void shouldDropFromTrash()
     {
         // Given a file in the trash
-        const QFile::Permissions origPerms = QFileInfo(m_srcFile).permissions();
+        const QFileInfo srcInfo(m_srcFile);
+        const QFile::Permissions origPerms = srcInfo.permissions();
         QVERIFY(QFileInfo(m_srcFile).isWritable());
         KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(m_srcFile), QUrl(QStringLiteral("trash:/")));
+
         QSignalSpy copyingDoneSpy(copyJob, &KIO::CopyJob::copyingDone);
         QVERIFY(copyJob->exec());
         const QUrl trashUrl = copyingDoneSpy.at(0).at(2).value<QUrl>();
         QVERIFY(trashUrl.isValid());
         QVERIFY(!QFile::exists(m_srcFile));
 
+        // trashinfo file was created
+        const QString infoFile(m_trashDir + QStringLiteral("/info/") + srcInfo.fileName() + QStringLiteral(".trashinfo"));
+        QVERIFY(QFileInfo::exists(infoFile));
+
         // When dropping the trashed file into a local dir, without modifiers
         m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, QUrl::fromLocalFile(m_srcDir), KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
         QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
@@ -315,6 +313,11 @@ private Q_SLOTS:
         KIO::StatJob *statJob = KIO::stat(trashUrl, KIO::HideProgressInfo);
         QVERIFY(!statJob->exec());
         QVERIFY(QFileInfo(m_srcFile).isWritable());
+
+        // trashinfo file was removed
+        QVERIFY(!QFileInfo::exists(infoFile));
+
+        QVERIFY(QFileInfo(m_srcFile).isWritable());
     }
 
     void shouldDropTrashRootWithoutMovingAllTrashedFiles() // #319660
@@ -332,7 +335,6 @@ private Q_SLOTS:
         m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
         QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
@@ -358,7 +360,6 @@ private Q_SLOTS:
         m_mimeData.setUrls(QList<QUrl>{trashUrl});
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, QUrl(QStringLiteral("trash:/")), KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
         QSignalSpy copyJobSpy(job, &KIO::DropJob::copyJobStarted);
         QSignalSpy spy(job, &KIO::DropJob::itemCreated);
 
@@ -367,7 +368,6 @@ private Q_SLOTS:
         QCOMPARE(job->error(), KIO::ERR_DROP_ON_ITSELF);
     }
 
-
     void shouldDropToDirectoryWithPopup_data()
     {
         QTest::addColumn<QString>("dest"); // empty for a temp dir
@@ -407,8 +407,6 @@ private Q_SLOTS:
         QUrl destUrl = QUrl::fromLocalFile(dest);
         QDropEvent dropEvent(QPoint(10, 10), Qt::CopyAction /*unused*/, &m_mimeData, Qt::LeftButton, Qt::NoModifier);
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
-        job->setUiDelegate(nullptr);
-        job->setUiDelegateExtension(nullptr); // no rename dialog
         JobSpy jobSpy(job);
         qRegisterMetaType<KFileItemListProperties>();
         QSignalSpy spyShow(job, &KIO::DropJob::popupMenuAboutToShow);
@@ -455,8 +453,8 @@ private Q_SLOTS:
         KIO::DropJob *job = KIO::drop(&dropEvent, destUrl, KIO::HideProgressInfo);
         QAction appAction1(QStringLiteral("action1"), this);
         QAction appAction2(QStringLiteral("action2"), this);
-        QList<QAction *> appActions; appActions << &appAction1 << &appAction2;
-        job->setUiDelegate(nullptr);
+        QList<QAction *> appActions;
+        appActions << &appAction1 << &appAction2;
         job->setApplicationActions(appActions);
         JobSpy jobSpy(job);
 
@@ -509,9 +507,9 @@ private:
     QString m_srcFile;
     QString m_srcLink;
     QTemporaryDir m_nonWritableTempDir;
+    QString m_trashDir;
 };
 
 QTEST_MAIN(DropJobTest)
 
 #include "dropjobtest.moc"
-
