@@ -343,6 +343,38 @@ void KDirListerTest::testNewItemByCopy()
     QCOMPARE(itemForUrl.entry().stringValue(KIO::UDSEntry::UDS_NAME), fileName);
 }
 
+void KDirListerTest::testNewItemByCopyInSubDir() // #440712
+{
+    // Test that copying a file to a directory whose parent is listed
+    // triggers refreshItems for the directory
+    const int origItemCount = m_items.count();
+    const QString path = tempPath();
+    connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
+    connect(&m_dirLister, &KDirLister::refreshItems, this, &KDirListerTest::slotRefreshItems);
+    QSignalSpy refreshItemSpy(this, &KDirListerTest::refreshItemsReceived);
+
+    const QUrl subDirUrl = QUrl::fromLocalFile(path + "subdir");
+    KFileItem itemForUrl = KDirLister::cachedItemForUrl(subDirUrl);
+    auto origModificationDate = itemForUrl.entry().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME);
+
+    const QString fileName = path + "subdir/toplevelfile_copy";
+    const QUrl itemUrl = QUrl::fromLocalFile(fileName);
+    KIO::CopyJob *job = KIO::copyAs(QUrl::fromLocalFile(path + "toplevelfile_3"), itemUrl, KIO::HideProgressInfo);
+    QVERIFY(job->exec());
+
+    QTRY_COMPARE(m_items.count(), origItemCount);
+
+    // Give some time to KDirNotify
+    QVERIFY(refreshItemSpy.wait(100));
+
+    itemForUrl = KDirLister::cachedItemForUrl(subDirUrl);
+    QVERIFY(itemForUrl.entry().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) > origModificationDate);
+
+    // clean leftover file
+    QVERIFY(QFile(fileName).remove());
+    m_refreshedItems.clear();
+}
+
 void KDirListerTest::testNewItemsInSymlink() // #213799
 {
     const int origItemCount = m_items.count();
@@ -360,15 +392,18 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     }
     MyDirLister dirLister2;
     m_items2.clear();
+    m_items.clear();
     connect(&dirLister2, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems2);
     connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
 
     // The initial listing
-    dirLister2.openUrl(QUrl::fromLocalFile(symPath), KDirLister::NoFlags);
+    m_dirLister.openUrl(QUrl::fromLocalFile(path));
+    dirLister2.openUrl(QUrl::fromLocalFile(symPath));
+    QTRY_COMPARE(m_items.count(), m_items2.count());
     QTRY_COMPARE(m_items.count(), origItemCount);
     QTRY_VERIFY(dirLister2.isFinished());
 
-    QTest::qWait(1000); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
+    QTest::qWait(100); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
 
     qDebug() << "Creating new file";
     const QString fileName = QStringLiteral("toplevelfile_newinlink");
@@ -396,17 +431,29 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     // Test file deletion
     {
         qDebug() << "Deleting" << (path + fileName);
-        QTest::qWait(1000); // for timestamp difference
+        QTest::qWait(100); // for timestamp difference
         QFile::remove(path + fileName);
         QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 1);
+        QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 1);
         const KFileItem item = dirLister2.spyItemsDeleted[0][0].value<KFileItemList>().at(0);
         QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName));
     }
+    // Test file deletion in symlink dir #469254
+    {
+        qDebug() << "Deleting" << (symPath + "/" + fileName2);
+        QTest::qWait(100); // for timestamp difference
+        QFile::remove(symPath + "/" + fileName2);
+        QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 2);
+        QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 2);
+        const KFileItem item = dirLister2.spyItemsDeleted[1][0].value<KFileItemList>().at(0);
+        QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName2));
+    }
 
     // TODO: test file update.
     disconnect(&m_dirLister, nullptr, this, nullptr);
 
     QFile::remove(symPath);
+    m_dirLister.openUrl(QUrl::fromLocalFile(tempPath()));
 }
 
 // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
@@ -1053,40 +1100,37 @@ void KDirListerTest::testBug211472()
     connect(&dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
 
     dirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&dirLister, qOverload<>(&KCoreDirLister::completed));
-    QVERIFY(spyCompleted.wait(1000));
+    QVERIFY(dirLister.spyCompleted.wait(1000));
     QVERIFY(dirLister.isFinished());
     QVERIFY(m_items.isEmpty());
 
-    if (true) {
-        // This block is required to trigger bug 211472.
+    // This block is required to trigger bug 211472.
 
-        // Go 'up' to the parent of 'newsubdir'.
-        dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
-        QVERIFY(spyCompleted.wait(1000));
-        QTRY_VERIFY(dirLister.isFinished());
-        QTRY_VERIFY(!m_items.isEmpty());
-        m_items.clear();
+    // Go 'up' to the parent of 'newsubdir'.
+    dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
+    QVERIFY(dirLister.spyCompleted.wait(1000));
+    QTRY_VERIFY(dirLister.isFinished());
+    QTRY_VERIFY(!m_items.isEmpty());
+    m_items.clear();
 
-        // Create a file in 'newsubdir' while we are listing its parent dir.
-        createTestFile(path + "newFile-1");
-        // At this point, newsubdir is not used, so it's moved to the cache.
-        // This happens in checkUpdate, called when receiving a notification for the cached dir,
-        // this is why this unittest needs to create a test file in the subdir.
+    // Create a file in 'newsubdir' while we are listing its parent dir.
+    createTestFile(path + "newFile-1");
+    // At this point, newsubdir is not used, so it's moved to the cache.
+    // This happens in checkUpdate, called when receiving a notification for the cached dir,
+    // this is why this unittest needs to create a test file in the subdir.
 
-        // wait a second and ensure the list is still empty afterwards
-        QTest::qWait(1000);
-        QTRY_VERIFY(m_items.isEmpty());
+    // wait a second and ensure the list is still empty afterwards
+    QTest::qWait(1000);
+    QTRY_VERIFY(m_items.isEmpty());
 
-        // Return to 'newsubdir'. It will be emitted from the cache, then an update will happen.
-        dirLister.openUrl(QUrl::fromLocalFile(path));
-        // Check that completed is emitted twice
-        QVERIFY(spyCompleted.wait(1000));
-        QVERIFY(spyCompleted.wait(1000));
-        QTRY_VERIFY(dirLister.isFinished());
-        QTRY_COMPARE(m_items.count(), 1);
-        m_items.clear();
-    }
+    // Return to 'newsubdir'. It will be emitted from the cache, then an update will happen.
+    dirLister.openUrl(QUrl::fromLocalFile(path));
+    // Check that completed is emitted twice
+    QVERIFY(dirLister.spyCompleted.wait(1000));
+    QVERIFY(dirLister.spyCompleted.wait(1000));
+    QTRY_VERIFY(dirLister.isFinished());
+    QTRY_COMPARE(m_items.count(), 1);
+    m_items.clear();
 
     // Now try to create a second file in 'newsubdir' and verify that the
     // dir lister notices it.
@@ -1612,13 +1656,11 @@ void KDirListerTest::testDeleteCurrentDir()
 void KDirListerTest::testForgetDir()
 {
     QTemporaryDir tempDir(homeTmpDir());
-    QString path = tempDir.path() + QLatin1Char('/');
+    QString path = tempDir.path();
     createTestFile(path + "/file_1");
 
-    QSignalSpy spyCompleted(&m_dirLister, qOverload<>(&KCoreDirLister::completed));
-
     m_dirLister.openUrl(QUrl::fromLocalFile(path), KDirLister::Keep);
-    QVERIFY(spyCompleted.wait());
+    QVERIFY(m_dirLister.spyCompleted.wait());
 
     m_dirLister.forgetDirs(QUrl::fromLocalFile(path));
 
@@ -1679,4 +1721,71 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
     qDebug() << "Waited" << totalWait << "ms so that now" << now.toString(Qt::ISODate) << "is >" << ctime.toString(Qt::ISODate);
 }
 
+// A bug in the decAutoUpdate/incAutoUpdate logic made KDirLister stop watching a directory for changes,
+// and stop watching a directory because a separate lister left a directory open in another lister
+void KDirListerTest::testBug386763()
+{
+    QTemporaryDir newDir(homeTmpDir());
+    const QString path = newDir.path() + "/newsubdir/";
+    const QString otherpath = newDir.path() + "/othersubdir/";
+
+    QDir().mkdir(path);
+    MyDirLister dirLister;
+    dirLister.openUrl(QUrl::fromLocalFile(path));
+
+    // second lister opening same dir
+    MyDirLister dirLister2;
+    dirLister2.openUrl(QUrl::fromLocalFile(path));
+    QCOMPARE(dirLister2.spyCompleted.count(), 0);
+
+    connect(&dirLister2, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
+    QVERIFY(dirLister.spyCompleted.wait(500));
+    QVERIFY(dirLister.isFinished());
+    QVERIFY(m_items.isEmpty());
+
+    // first lister opening another dir
+    dirLister.openUrl(QUrl::fromLocalFile(otherpath));
+
+    // Create a file in 'newsubdir' while still opened in dirLister2
+    // bug was that the watch on ’newsubdir’ when dirLister left this dir
+    // eventhough dirLister2 is still listing it
+    QCOMPARE(dirLister2.spyCompleted.count(), 1);
+    createTestFile(path + "newFile-1");
+
+    QTRY_COMPARE(m_items.count(), 1);
+    QVERIFY(KDirWatch::self()->contains(path));
+
+    dirLister2.openUrl(QUrl::fromLocalFile(otherpath));
+    // checks we still watch the old path when second lister leaves it as it should be now in cache
+    QVERIFY(KDirWatch::self()->contains(path));
+
+    newDir.remove();
+}
+
+void KDirListerTest::testCacheEviction()
+{
+    QTemporaryDir newDir(homeTmpDir());
+
+    MyDirLister dirLister;
+    dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
+    QVERIFY(dirLister.spyCompleted.wait(500));
+    QVERIFY(dirLister.isFinished());
+    QVERIFY(KDirWatch::self()->contains(newDir.path()));
+
+    for (int i = 0; i < 12; i++) {
+        const QString newDirPath = newDir.path() + QString("dir_%1").arg(i);
+        QVERIFY(QDir().mkdir(newDirPath));
+
+        dirLister.openUrl(QUrl::fromLocalFile(newDirPath));
+        QVERIFY(dirLister.spyCompleted.wait(500));
+        QVERIFY(dirLister.isFinished());
+        QVERIFY(KDirWatch::self()->contains(newDirPath));
+    }
+
+    // watches were removed as the dirItem were evicted from cache
+    QVERIFY(!KDirWatch::self()->contains(newDir.path()));
+    QVERIFY(!KDirWatch::self()->contains(newDir.path() + QString("dir_0")));
+    QVERIFY(KDirWatch::self()->contains(newDir.path() + QString("dir_1")));
+}
+
 #include "moc_kdirlistertest.cpp"
