@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KFILEITEMTEST_H
 #define KFILEITEMTEST_H
@@ -31,11 +19,13 @@ private Q_SLOTS:
     void testDoesNotExist();
     void testDetach();
     void testMove();
+    void testMimeTypeCtor();
     void testBasic();
     void testRootDirectory();
     void testHiddenFile();
     void testMimeTypeOnDemand();
     void testCmp();
+    void testCmpAndInit();
     void testCmpByUrl();
     void testRename();
     void testRefresh();
