@@ -7,10 +7,10 @@
 
 #include "udsentrytest.h"
 
-#include <QTest>
-#include <QVector>
 #include <QDataStream>
 #include <QTemporaryFile>
+#include <QTest>
+#include <QVector>
 #include <qplatformdefs.h>
 
 #include <kfileitem.h>
@@ -19,18 +19,20 @@
 #include "kiotesthelper.h"
 
 struct UDSTestField {
-    UDSTestField() {}
+    UDSTestField()
+    {
+    }
 
-    UDSTestField(uint uds, const QString &value) :
-        m_uds(uds),
-        m_string(value)
+    UDSTestField(uint uds, const QString &value)
+        : m_uds(uds)
+        , m_string(value)
     {
         Q_ASSERT(uds & KIO::UDSEntry::UDS_STRING);
     }
 
-    UDSTestField(uint uds, long long value) :
-        m_uds(uds),
-        m_long(value)
+    UDSTestField(uint uds, long long value)
+        : m_uds(uds)
+        , m_long(value)
     {
         Q_ASSERT(uds & KIO::UDSEntry::UDS_NUMBER);
     }
@@ -45,73 +47,61 @@ struct UDSTestField {
  */
 void UDSEntryTest::testSaveLoad()
 {
-    const QVector<QVector<UDSTestField> > testCases {
-        // Data for 1st UDSEntry.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 1),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user1")),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename1")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 123456),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 12345),
-        UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 2),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 56)
-        },
-        // 2nd entry: change some of the data.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user2")),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename2")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12345),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1234),
-        UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 42)
-        },
-        // 3rd entry: keep the data, but change the order of the entries.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user2")),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename2")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12345),
-        UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1234),
-        },
-        // 4th entry: change some of the data and the order of the entries.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user4")),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
-        UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename4"))
-        },
-        // 5th entry: remove one field.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user4")),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename4"))
-        },
-        // 6th entry: add a new field, and change some others.
-        {
-        UDSTestField(KIO::UDSEntry::UDS_SIZE, 89),
-        UDSTestField(KIO::UDSEntry::UDS_ICON_NAME, QStringLiteral("icon6")),
-        UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user6")),
-        UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
-        UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
-        UDSTestField(KIO::UDSEntry::UDS_INODE, 32),
-        UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
-        UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename6"))
-        }
-    };
+    const QVector<QVector<UDSTestField>> testCases{// Data for 1st UDSEntry.
+                                                   {UDSTestField(KIO::UDSEntry::UDS_SIZE, 1),
+                                                    UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user1")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename1")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 123456),
+                                                    UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 12345),
+                                                    UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 2),
+                                                    UDSTestField(KIO::UDSEntry::UDS_INODE, 56)},
+                                                   // 2nd entry: change some of the data.
+                                                   {UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
+                                                    UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user2")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename2")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12345),
+                                                    UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1234),
+                                                    UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
+                                                    UDSTestField(KIO::UDSEntry::UDS_INODE, 42)},
+                                                   // 3rd entry: keep the data, but change the order of the entries.
+                                                   {
+                                                       UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
+                                                       UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group1")),
+                                                       UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user2")),
+                                                       UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename2")),
+                                                       UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12345),
+                                                       UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
+                                                       UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
+                                                       UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1234),
+                                                   },
+                                                   // 4th entry: change some of the data and the order of the entries.
+                                                   {UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
+                                                    UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user4")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
+                                                    UDSTestField(KIO::UDSEntry::UDS_DEVICE_ID, 87),
+                                                    UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
+                                                    UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
+                                                    UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename4"))},
+                                                   // 5th entry: remove one field.
+                                                   {UDSTestField(KIO::UDSEntry::UDS_SIZE, 2),
+                                                    UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user4")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
+                                                    UDSTestField(KIO::UDSEntry::UDS_INODE, 42),
+                                                    UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
+                                                    UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename4"))},
+                                                   // 6th entry: add a new field, and change some others.
+                                                   {UDSTestField(KIO::UDSEntry::UDS_SIZE, 89),
+                                                    UDSTestField(KIO::UDSEntry::UDS_ICON_NAME, QStringLiteral("icon6")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_USER, QStringLiteral("user6")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_GROUP, QStringLiteral("group4")),
+                                                    UDSTestField(KIO::UDSEntry::UDS_MODIFICATION_TIME, 12346),
+                                                    UDSTestField(KIO::UDSEntry::UDS_INODE, 32),
+                                                    UDSTestField(KIO::UDSEntry::UDS_CREATION_TIME, 1235),
+                                                    UDSTestField(KIO::UDSEntry::UDS_NAME, QStringLiteral("filename6"))}};
     // Store the entries in a QByteArray.
     QByteArray data;
     {
@@ -164,7 +154,7 @@ void UDSEntryTest::testSaveLoad()
     {
         QDataStream stream(&data, QIODevice::WriteOnly);
         for (const QVector<UDSTestField> &testCase : testCases) {
-            stream << testCase.count();
+            stream << static_cast<quint32>(testCase.count());
 
             for (const UDSTestField &field : testCase) {
                 uint uds = field.m_uds;
@@ -275,7 +265,7 @@ void UDSEntryTest::testEquality()
     entry2.fastInsert(KIO::UDSEntry::UDS_DEVICE_ID, 2);
     entry2.fastInsert(KIO::UDSEntry::UDS_INODE, 56);
 
-    // 3nd entry: different user.
+    // 3rd entry: different user.
     KIO::UDSEntry entry3;
     entry3.fastInsert(KIO::UDSEntry::UDS_SIZE, 1);
     entry3.fastInsert(KIO::UDSEntry::UDS_USER, QStringLiteral("other user"));
@@ -320,3 +310,5 @@ void UDSEntryTest::testEquality()
 }
 
 QTEST_MAIN(UDSEntryTest)
+
+#include "moc_udsentrytest.cpp"
