@@ -66,8 +66,8 @@ private:
 private Q_SLOTS:
     void initTestCase()
     {
-        // Force the http/webdav slave from our bindir as first choice. This specifically
-        // works around the fact that kioslave would load the slave from the system
+        // Force the http/webdav worker from our bindir as first choice. This specifically
+        // works around the fact that the kioslave executable would load the worker from the system
         // as first choice instead of the one from the build dir.
         qputenv("QT_PLUGIN_PATH", QCoreApplication::applicationDirPath().toUtf8());
 
@@ -82,7 +82,6 @@ private Q_SLOTS:
         });
 
         QStandardPaths::setTestModeEnabled(true);
-        qputenv("KDE_FORK_SLAVES", "yes");
     }
 
     void cleanupTestCase()
