@@ -7,9 +7,7 @@
 
 #include "filejob.h"
 
-#include "scheduler.h"
 #include "slave.h"
-#include "slavebase.h"
 
 #include "job_p.h"
 
