@@ -17,6 +17,8 @@
 #include <QSslConfiguration>
 #include <QSslSocket>
 
+#include <memory>
+
 // All classes here are deprecated, no need for clazy to bother
 // clazy:excludeall=overloaded-signal,fully-qualified-moc-types
 
@@ -59,7 +61,7 @@ public:
     QByteArray toDer() const;
 
 private:
-    KSslKeyPrivate *const d;
+    std::unique_ptr<KSslKeyPrivate> const d;
 };
 
 class KSslCipherPrivate;
@@ -89,7 +91,7 @@ public:
     static QList<KSslCipher> supportedCiphers();
 
 private:
-    KSslCipherPrivate *const d;
+    std::unique_ptr<KSslCipherPrivate> const d;
 };
 
 class KSslErrorPrivate;
@@ -138,11 +140,11 @@ public:
     QSslError sslError() const;
 
 private:
-    KSslErrorPrivate *const d;
+    std::unique_ptr<KSslErrorPrivate> const d;
 };
 
 // consider killing more convenience functions with huge signatures
-//### do we need setSession() / session() ?
+// ### do we need setSession() / session() ?
 
 // BIG FAT TODO: do we keep openMode() up to date everywhere it can change?
 
@@ -233,7 +235,7 @@ public:
     enum EncryptionMode {
         UnencryptedMode = 0,
         SslClientMode,
-        SslServerMode, //### not implemented
+        SslServerMode, // ### not implemented
     };
     enum ProxyPolicy {
         /// Use the proxy that KProtocolManager suggests for the connection parameters given.
@@ -243,7 +245,7 @@ public:
     };
 
     KTcpSocket(QObject *parent = nullptr);
-    ~KTcpSocket();
+    ~KTcpSocket() override;
 
     // from QIODevice
     // reimplemented virtuals - the ones not reimplemented are OK for us
@@ -255,7 +257,7 @@ public:
     bool isSequential() const override;
     bool open(QIODevice::OpenMode open) override;
     bool waitForBytesWritten(int msecs) override;
-    //### Document that this actually tries to read *more* data
+    // ### Document that this actually tries to read *more* data
     bool waitForReadyRead(int msecs = 30000) override;
 
 protected:
@@ -280,9 +282,9 @@ public:
      */
     void connectToHost(const QUrl &url, ProxyPolicy policy = AutoProxy);
     void disconnectFromHost();
-    Error error() const; //### QAbstractSocket's model is strange. error() should be related to the
+    Error error() const; // ### QAbstractSocket's model is strange. error() should be related to the
     // current state and *NOT* just report the last error if there was one.
-    QList<KSslError> sslErrors() const; //### the errors returned can only have a subset of all
+    QList<KSslError> sslErrors() const; // ### the errors returned can only have a subset of all
     // possible QSslError::SslError enum values depending on backend
     bool flush();
     bool isValid() const;
@@ -326,7 +328,7 @@ public:
     KSslCipher sessionCipher() const;
     void setCaCertificates(const QList<QSslCertificate> &certificates);
     void setCiphers(const QList<KSslCipher> &ciphers);
-    //### void setCiphers(const QString &ciphers); //what about i18n?
+    // ### void setCiphers(const QString &ciphers); //what about i18n?
     void setLocalCertificate(const QSslCertificate &certificate);
     void setLocalCertificate(const QString &fileName, QSsl::EncodingFormat format = QSsl::Pem);
     void setPrivateKey(const KSslKey &key);
@@ -406,7 +408,7 @@ private:
     void showSslErrors();
 
     friend class KTcpSocketPrivate;
-    KTcpSocketPrivate *const d;
+    std::unique_ptr<KTcpSocketPrivate> const d;
 };
 
 #endif // deprecated since 5.65
