@@ -1,38 +1,27 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mkdirjob.h"
 #include "job.h"
 #include "job_p.h"
-#include <slave.h>
-#include <kurlauthorized.h>
 #include "kiocoredebug.h"
+#include <kurlauthorized.h>
+#include <slave.h>
 
 using namespace KIO;
 
-class KIO::MkdirJobPrivate: public SimpleJobPrivate
+class KIO::MkdirJobPrivate : public SimpleJobPrivate
 {
 public:
     MkdirJobPrivate(const QUrl &url, int command, const QByteArray &packedArgs)
         : SimpleJobPrivate(url, command, packedArgs)
-    { }
+    {
+    }
     QUrl m_redirectionURL;
     void slotRedirection(const QUrl &url);
 
@@ -42,7 +31,7 @@ public:
      * work on this job.
      * @param slave the slave that starts working on this job
      */
-    void start(Slave *slave) Q_DECL_OVERRIDE;
+    void start(Slave *slave) override;
 
     Q_DECLARE_PUBLIC(MkdirJob)
 
@@ -66,17 +55,18 @@ MkdirJob::~MkdirJob()
 void MkdirJobPrivate::start(Slave *slave)
 {
     Q_Q(MkdirJob);
-    q->connect(slave, SIGNAL(redirection(QUrl)),
-               SLOT(slotRedirection(QUrl)));
+    q->connect(slave, &KIO::SlaveInterface::redirection, q, [this](const QUrl &url) {
+        slotRedirection(url);
+    });
 
     SimpleJobPrivate::start(slave);
 }
 
-// Slave got a redirection request
+// Worker got a redirection request
 void MkdirJobPrivate::slotRedirection(const QUrl &url)
 {
     Q_Q(MkdirJob);
-    //qDebug() << url;
+    // qDebug() << url;
     if (!KUrlAuthorized::authorizeUrlAction(QStringLiteral("redirect"), m_url, url)) {
         qCWarning(KIO_CORE) << "Redirection from" << m_url << "to" << url << "REJECTED!";
         q->setError(ERR_ACCESS_DENIED);
@@ -85,7 +75,7 @@ void MkdirJobPrivate::slotRedirection(const QUrl &url)
     }
     m_redirectionURL = url; // We'll remember that when the job finishes
     // Tell the user that we haven't finished yet
-    emit q->redirection(q, m_redirectionURL);
+    Q_EMIT q->redirection(q, m_redirectionURL);
 }
 
 void MkdirJob::slotFinished()
@@ -93,9 +83,9 @@ void MkdirJob::slotFinished()
     Q_D(MkdirJob);
 
     if (!d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid()) {
-        //qDebug() << "MkdirJob: Redirection to " << m_redirectionURL;
+        // qDebug() << "MkdirJob: Redirection to " << m_redirectionURL;
         if (queryMetaData(QStringLiteral("permanent-redirect")) == QLatin1String("true")) {
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
+            Q_EMIT permanentRedirection(this, d->m_url, d->m_redirectionURL);
         }
 
         if (d->m_redirectionHandlingEnabled) {
@@ -119,7 +109,7 @@ void MkdirJob::slotFinished()
 
 KIO::MkdirJob *KIO::mkdir(const QUrl &url, int permissions)
 {
-    //qDebug() << "mkdir " << url;
+    // qDebug() << "mkdir " << url;
     KIO_ARGS << url << permissions;
     return MkdirJobPrivate::newJob(url, CMD_MKDIR, packedArgs);
 }
