@@ -45,11 +45,9 @@ protected Q_SLOTS:
     void slotResult(KJob *job) override;
 
 protected:
-    RestoreJob(RestoreJobPrivate &dd);
+    KIOCORE_NO_EXPORT explicit RestoreJob(RestoreJobPrivate &dd);
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void slotStart())
-
     Q_DECLARE_PRIVATE(RestoreJob)
 };
 
