@@ -68,7 +68,9 @@ public:
         , m_job(nullptr)
         , m_pid(0)
         , m_port(0)
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
         , contacted(false)
+#endif
         , dead(false)
         , m_refCount(1)
     {
@@ -93,7 +95,9 @@ public:
     KIO::SimpleJob *m_job;
     qint64 m_pid; // only set for out-of-process workers
     quint16 m_port;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
     bool contacted;
+#endif
     bool dead;
     QElapsedTimer contact_started;
     QElapsedTimer m_idleSince;
@@ -121,24 +125,24 @@ void Slave::timeout()
         return;
     }
 
-    /*qDebug() << "slave failed to connect to application pid=" << d->m_pid
+    /*qDebug() << "worker failed to connect to application pid=" << d->m_pid
                  << " protocol=" << d->m_protocol;*/
     if (d->m_pid && KIOPrivate::isProcessAlive(d->m_pid)) {
         int delta_t = d->contact_started.elapsed() / 1000;
-        // qDebug() << "slave is slow... pid=" << d->m_pid << " t=" << delta_t;
+        // qDebug() << "worker is slow... pid=" << d->m_pid << " t=" << delta_t;
         if (delta_t < s_slaveConnectionTimeoutMax) {
             QTimer::singleShot(1000 * s_slaveConnectionTimeoutMin, this, &Slave::timeout);
             return;
         }
     }
-    // qDebug() << "Houston, we lost our slave, pid=" << d->m_pid;
+    // qDebug() << "Houston, we lost our worker, pid=" << d->m_pid;
     d->connection->close();
     d->dead = true;
     QString arg = d->m_protocol;
     if (!d->m_host.isEmpty()) {
         arg += QLatin1String("://") + d->m_host;
     }
-    // qDebug() << "slave failed to connect pid =" << d->m_pid << arg;
+    // qDebug() << "worker failed to connect pid =" << d->m_pid << arg;
 
     ref();
     // Tell the job about the problem.
@@ -212,17 +216,21 @@ void Slave::setIdle()
     d->m_idleSince.start();
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 bool Slave::isConnected()
 {
     Q_D(Slave);
     return d->contacted;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 void Slave::setConnected(bool c)
 {
     Q_D(Slave);
     d->contacted = c;
 }
+#endif
 
 void Slave::ref()
 {
@@ -350,7 +358,7 @@ void Slave::gotInput()
         if (!d->m_host.isEmpty()) {
             arg += QLatin1String("://") + d->m_host;
         }
-        // qDebug() << "slave died pid =" << d->m_pid << arg;
+        // qDebug() << "worker died pid =" << d->m_pid << arg;
         // Tell the job about the problem.
         Q_EMIT error(ERR_WORKER_DIED, arg);
         // Tell the scheduler about the problem.
@@ -423,13 +431,13 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
         return nullptr;
     }
 
-    // find the kioslave using QPluginLoader; kioslave would do this
+    // find the KIO worker using QPluginLoader; kioslave would do this
     // anyway, but if it doesn't exist, we want to be able to return
     // a useful error message immediately
     QPluginLoader loader(_name);
     const QString lib_path = loader.fileName();
     if (lib_path.isEmpty()) {
-        error_text = i18n("Can not find io-slave for protocol '%1'.", protocol);
+        error_text = i18n("Can not find a KIO worker for protocol '%1'.", protocol);
         error = KIO::ERR_CANNOT_CREATE_WORKER;
         return nullptr;
     }
@@ -437,7 +445,7 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
     Slave *slave = new Slave(protocol);
     QUrl slaveAddress = slave->d_func()->slaveconnserver->address();
     if (slaveAddress.isEmpty()) {
-        error_text = i18n("Can not create socket for launching io-slave for protocol '%1'.", protocol);
+        error_text = i18n("Can not create a socket for launching a KIO worker for protocol '%1'.", protocol);
         error = KIO::ERR_CANNOT_CREATE_WORKER;
         delete slave;
         return nullptr;
@@ -451,7 +459,7 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
 
     // Threads have performance benefits, but degrade robustness
     // (a worker crashing kills the app). So let's only enable the feature for kio_file, for now.
-    if (bUseThreads && protocol == QLatin1String("file")) {
+    if (protocol == QLatin1String("admin") || (bUseThreads && protocol == QLatin1String("file"))) {
         auto *factory = qobject_cast<WorkerFactory *>(loader.instance());
         if (factory) {
             auto *thread = new WorkerThread(slave, factory, slaveAddress.toString().toLocal8Bit());
@@ -505,3 +513,5 @@ bool Slave::checkForHeldSlave(const QUrl &)
     return false;
 }
 #endif
+
+#include "moc_slave.cpp"
