@@ -13,10 +13,10 @@
 #include <winsock2.h> // struct timeval
 #endif
 
-#include "global.h"
 #include "connection_p.h"
-#include <QTimer>
+#include "global.h"
 #include <QHostInfo>
+#include <QTimer>
 
 #include "kiocoredebug.h"
 
@@ -26,8 +26,13 @@ class KIO::SlaveInterfacePrivate
 {
 public:
     SlaveInterfacePrivate()
-        : connection(nullptr), filesize(0), offset(0), last_time(0), start_time(0),
-          nums(0), slave_calcs_speed(false)
+        : connection(nullptr)
+        , filesize(0)
+        , offset(0)
+        , last_time(0)
+        , start_time(0)
+        , nums(0)
+        , slave_calcs_speed(false)
     {
     }
     virtual ~SlaveInterfacePrivate()
@@ -41,9 +46,9 @@ public:
     // We need some metadata here for our SSL code in messageBox() and for sslMetaData().
     MetaData sslMetaData;
 
-    // Since 5.66 this is used for sending privilege operation details.
-    // KF6 TODO remove this hack.
-    MetaData privilegeConfMetaData;
+    // Used to cache privilege operation details passed from the worker by the metadata hack
+    // See WORKER_MESSAGEBOX_DETAILS_HACK
+    QString messageBoxDetails;
 
     KIO::filesize_t sizes[max_nums];
     qint64 times[max_nums];
