@@ -13,15 +13,14 @@
 
 namespace KIO
 {
-
 class TransferJobPrivate;
 /**
  * @class KIO::TransferJob transferjob.h <KIO/TransferJob>
  *
- * The transfer job pumps data into and/or out of a Slave.
- * Data is sent to the slave on request of the slave ( dataReq).
- * If data coming from the slave can not be handled, the
- * reading of data from the slave should be suspended.
+ * The transfer job pumps data into and/or out of a KIO worker.
+ * Data is sent to the worker on request of the worker ( dataReq).
+ * If data coming from the worker can not be handled, the
+ * reading of data from the worker should be suspended.
  */
 class KIOCORE_EXPORT TransferJob : public SimpleJob
 {
@@ -32,7 +31,7 @@ public:
 
     /**
      * Sets the modification time of the file to be created (by KIO::put)
-     * Note that some kioslaves might ignore this.
+     * Note that some KIO workers might ignore this.
      */
     void setModificationTime(const QDateTime &mtime);
 
@@ -121,9 +120,9 @@ protected:
 
 Q_SIGNALS:
     /**
-     * Data from the slave has arrived.
+     * Data from the worker has arrived.
      * @param job the job that emitted this signal
-     * @param data data received from the slave.
+     * @param data data received from the worker.
      *
      * End of data (EOD) has been reached if data.size() == 0, however, you
      * should not be certain of data.size() == 0 ever happening (e.g. in case
@@ -140,7 +139,7 @@ Q_SIGNALS:
      *
      * @param job the job that emitted this signal
      * @param data buffer to fill with data to send to the
-     * slave. An empty buffer indicates end of data. (EOD)
+     * worker. An empty buffer indicates end of data. (EOD)
      */
     void dataReq(KIO::Job *job, QByteArray &data);
 
@@ -170,7 +169,7 @@ Q_SIGNALS:
      * @deprecated Since 5.78, use mimeTypeFound(KIO::Job *, const QString &)
      */
     KIOCORE_DEPRECATED_VERSION(5, 78, "Use KIO::TransferJob::mimeTypeFound(KIO::Job *, const QString &)")
-    void mimetype(KIO::Job *job, const QString &mimeType);
+    void mimetype(KIO::Job *job, const QString &mimeType); // clazy:exclude=overloaded-signal
 #endif
 
     /**
@@ -196,14 +195,14 @@ protected Q_SLOTS:
     virtual void slotData(const QByteArray &data);
     virtual void slotDataReq();
     virtual void slotMimetype(const QString &mimetype);
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101) // override no longer needed
     void slotMetaData(const KIO::MetaData &_metaData) override;
+#endif
 
 protected:
-    TransferJob(TransferJobPrivate &dd);
+    KIOCORE_NO_EXPORT explicit TransferJob(TransferJobPrivate &dd);
+
 private:
-    Q_PRIVATE_SLOT(d_func(), void slotPostRedirection())
-    Q_PRIVATE_SLOT(d_func(), void slotIODeviceClosed())
-    Q_PRIVATE_SLOT(d_func(), void slotIODeviceClosedBeforeStart())
     Q_DECLARE_PRIVATE(TransferJob)
 
     // A FileCopyJob may control one or more TransferJobs
@@ -214,7 +213,7 @@ private:
 /**
  * Get (means: read).
  * This is the job to use in order to "download" a file into memory.
- * The slave emits the data through the data() signal.
+ * The worker emits the data through the data() signal.
  *
  * Special case: if you want to determine the MIME type of the file first,
  * and then read it with the appropriate component, you can still use
@@ -247,8 +246,7 @@ KIOCORE_EXPORT TransferJob *get(const QUrl &url, LoadType reload = NoReload, Job
  * @return the job handling the operation.
  * @see multi_get()
  */
-KIOCORE_EXPORT TransferJob *put(const QUrl &url, int permissions,
-                                JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT TransferJob *put(const QUrl &url, int permissions, JobFlags flags = DefaultFlags);
 
 /**
  * HTTP POST (for form data).
@@ -278,8 +276,7 @@ KIOCORE_EXPORT TransferJob *put(const QUrl &url, int permissions,
  * @param flags Can be HideProgressInfo here
  * @return the job handling the operation.
  */
-KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, const QByteArray &postData,
-                                      JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, const QByteArray &postData, JobFlags flags = DefaultFlags);
 
 /**
  * HTTP POST.
@@ -297,8 +294,7 @@ KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, const QByteArray &postDat
  *
  * @since 4.7
  */
-KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, QIODevice *device,
-                                      qint64 size = -1, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, QIODevice *device, qint64 size = -1, JobFlags flags = DefaultFlags);
 
 /**
  * HTTP DELETE.
