@@ -10,17 +10,18 @@
 
 #include "udsentry.h"
 
-#include <QString>
-#include <QList>
+#include "../utils_p.h"
+
 #include <QDataStream>
-#include <QVector>
 #include <QDebug>
+#include <QString>
+#include <QVector>
 
 #include <KUser>
 
 using namespace KIO;
 
-//BEGIN UDSEntryPrivate
+// BEGIN UDSEntryPrivate
 /* ---------- UDSEntryPrivate ------------ */
 
 class KIO::UDSEntryPrivate : public QSharedData
@@ -50,11 +51,20 @@ public:
     static QString nameOfUdsField(uint field);
 
 private:
-    struct Field
-    {
-        inline Field() {}
-        inline Field(const uint index, const QString &value) : m_str(value), m_index(index) {}
-        inline Field(const uint index, long long value = 0) : m_long(value), m_index(index) {}
+    struct Field {
+        inline Field()
+        {
+        }
+        inline Field(const uint index, const QString &value)
+            : m_str(value)
+            , m_index(index)
+        {
+        }
+        inline Field(const uint index, long long value = 0)
+            : m_long(value)
+            , m_index(index)
+        {
+        }
 
         QString m_str;
         long long m_long = LLONG_MIN;
@@ -71,16 +81,21 @@ void UDSEntryPrivate::reserve(int size)
 void UDSEntryPrivate::insert(uint udsField, const QString &value)
 {
     Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
-    Q_ASSERT(std::find_if(storage.cbegin(), storage.cend(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;}) == storage.cend());
+    Q_ASSERT(std::find_if(storage.cbegin(),
+                          storage.cend(),
+                          [udsField](const Field &entry) {
+                              return entry.m_index == udsField;
+                          })
+             == storage.cend());
     storage.emplace_back(udsField, value);
 }
 
 void UDSEntryPrivate::replace(uint udsField, const QString &value)
 {
     Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
-    auto it = std::find_if(storage.begin(), storage.end(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;});
+    auto it = std::find_if(storage.begin(), storage.end(), [udsField](const Field &entry) {
+        return entry.m_index == udsField;
+    });
     if (it != storage.end()) {
         it->m_str = value;
         return;
@@ -91,16 +106,21 @@ void UDSEntryPrivate::replace(uint udsField, const QString &value)
 void UDSEntryPrivate::insert(uint udsField, long long value)
 {
     Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
-    Q_ASSERT(std::find_if(storage.cbegin(), storage.cend(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;}) == storage.cend());
+    Q_ASSERT(std::find_if(storage.cbegin(),
+                          storage.cend(),
+                          [udsField](const Field &entry) {
+                              return entry.m_index == udsField;
+                          })
+             == storage.cend());
     storage.emplace_back(udsField, value);
 }
 
 void UDSEntryPrivate::replace(uint udsField, long long value)
 {
     Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
-    auto it = std::find_if(storage.begin(), storage.end(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;});
+    auto it = std::find_if(storage.begin(), storage.end(), [udsField](const Field &entry) {
+        return entry.m_index == udsField;
+    });
     if (it != storage.end()) {
         it->m_long = value;
         return;
@@ -115,8 +135,9 @@ int UDSEntryPrivate::count() const
 
 QString UDSEntryPrivate::stringValue(uint udsField) const
 {
-    auto it = std::find_if(storage.cbegin(), storage.cend(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;});
+    auto it = std::find_if(storage.cbegin(), storage.cend(), [udsField](const Field &entry) {
+        return entry.m_index == udsField;
+    });
     if (it != storage.cend()) {
         return it->m_str;
     }
@@ -125,8 +146,9 @@ QString UDSEntryPrivate::stringValue(uint udsField) const
 
 long long UDSEntryPrivate::numberValue(uint udsField, long long defaultValue) const
 {
-    auto it = std::find_if(storage.cbegin(), storage.cend(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;});
+    auto it = std::find_if(storage.cbegin(), storage.cend(), [udsField](const Field &entry) {
+        return entry.m_index == udsField;
+    });
     if (it != storage.cend()) {
         return it->m_long;
     }
@@ -157,8 +179,9 @@ QVector<uint> UDSEntryPrivate::fields() const
 
 bool UDSEntryPrivate::contains(uint udsField) const
 {
-    auto it = std::find_if(storage.cbegin(), storage.cend(),
-                                [udsField](const Field &entry) {return entry.m_index == udsField;});
+    auto it = std::find_if(storage.cbegin(), storage.cend(), [udsField](const Field &entry) {
+        return entry.m_index == udsField;
+    });
     return (it != storage.cend());
 }
 
@@ -196,7 +219,7 @@ void UDSEntryPrivate::load(QDataStream &s)
     // We cache the loaded strings. Some of them, like, e.g., the user,
     // will often be the same for many entries in a row. Caching them
     // permits to use implicit sharing to save memory.
-    static QVector<QString> cachedStrings;
+    thread_local QVector<QString> cachedStrings;
     if (quint32(cachedStrings.size()) < size) {
         cachedStrings.resize(size);
     }
@@ -230,68 +253,68 @@ void UDSEntryPrivate::load(QDataStream &s)
 QString UDSEntryPrivate::nameOfUdsField(uint field)
 {
     switch (field) {
-        case UDSEntry::UDS_SIZE:
-            return QStringLiteral("UDS_SIZE");
-        case UDSEntry::UDS_SIZE_LARGE:
-            return QStringLiteral("UDS_SIZE_LARGE");
-        case UDSEntry::UDS_USER:
-            return QStringLiteral("UDS_USER");
-        case UDSEntry::UDS_ICON_NAME:
-            return QStringLiteral("UDS_ICON_NAME");
-        case UDSEntry::UDS_GROUP:
-            return QStringLiteral("UDS_GROUP");
-        case UDSEntry::UDS_NAME:
-            return QStringLiteral("UDS_NAME");
-        case UDSEntry::UDS_LOCAL_PATH:
-            return QStringLiteral("UDS_LOCAL_PATH");
-        case UDSEntry::UDS_HIDDEN:
-            return QStringLiteral("UDS_HIDDEN");
-        case UDSEntry::UDS_ACCESS:
-            return QStringLiteral("UDS_ACCESS");
-        case UDSEntry::UDS_MODIFICATION_TIME:
-            return QStringLiteral("UDS_MODIFICATION_TIME");
-        case UDSEntry::UDS_ACCESS_TIME:
-            return QStringLiteral("UDS_ACCESS_TIME");
-        case UDSEntry::UDS_CREATION_TIME:
-            return QStringLiteral("UDS_CREATION_TIME");
-        case UDSEntry::UDS_FILE_TYPE:
-            return QStringLiteral("UDS_FILE_TYPE");
-        case UDSEntry::UDS_LINK_DEST:
-            return QStringLiteral("UDS_LINK_DEST");
-        case UDSEntry::UDS_URL:
-            return QStringLiteral("UDS_URL");
-        case UDSEntry::UDS_MIME_TYPE:
-            return QStringLiteral("UDS_MIME_TYPE");
-        case UDSEntry::UDS_GUESSED_MIME_TYPE:
-            return QStringLiteral("UDS_GUESSED_MIME_TYPE");
-        case UDSEntry::UDS_XML_PROPERTIES:
-            return QStringLiteral("UDS_XML_PROPERTIES");
-        case UDSEntry::UDS_EXTENDED_ACL:
-            return QStringLiteral("UDS_EXTENDED_ACL");
-        case UDSEntry::UDS_ACL_STRING:
-            return QStringLiteral("UDS_ACL_STRING");
-        case UDSEntry::UDS_DEFAULT_ACL_STRING:
-            return QStringLiteral("UDS_DEFAULT_ACL_STRING");
-        case UDSEntry::UDS_DISPLAY_NAME:
-            return QStringLiteral("UDS_DISPLAY_NAME");
-        case UDSEntry::UDS_TARGET_URL:
-            return QStringLiteral("UDS_TARGET_URL");
-        case UDSEntry::UDS_DISPLAY_TYPE:
-            return QStringLiteral("UDS_DISPLAY_TYPE");
-        case UDSEntry::UDS_ICON_OVERLAY_NAMES:
-            return QStringLiteral("UDS_ICON_OVERLAY_NAMES");
-        case UDSEntry::UDS_COMMENT:
-            return QStringLiteral("UDS_COMMENT");
-        case UDSEntry::UDS_DEVICE_ID:
-            return QStringLiteral("UDS_DEVICE_ID");
-        case UDSEntry::UDS_INODE:
-            return QStringLiteral("UDS_INODE");
-        case UDSEntry::UDS_EXTRA:
-            return QStringLiteral("UDS_EXTRA");
-        case UDSEntry::UDS_EXTRA_END:
-            return QStringLiteral("UDS_EXTRA_END");
-        default:
-            return QStringLiteral("Unknown uds field %1").arg(field);
+    case UDSEntry::UDS_SIZE:
+        return QStringLiteral("UDS_SIZE");
+    case UDSEntry::UDS_SIZE_LARGE:
+        return QStringLiteral("UDS_SIZE_LARGE");
+    case UDSEntry::UDS_USER:
+        return QStringLiteral("UDS_USER");
+    case UDSEntry::UDS_ICON_NAME:
+        return QStringLiteral("UDS_ICON_NAME");
+    case UDSEntry::UDS_GROUP:
+        return QStringLiteral("UDS_GROUP");
+    case UDSEntry::UDS_NAME:
+        return QStringLiteral("UDS_NAME");
+    case UDSEntry::UDS_LOCAL_PATH:
+        return QStringLiteral("UDS_LOCAL_PATH");
+    case UDSEntry::UDS_HIDDEN:
+        return QStringLiteral("UDS_HIDDEN");
+    case UDSEntry::UDS_ACCESS:
+        return QStringLiteral("UDS_ACCESS");
+    case UDSEntry::UDS_MODIFICATION_TIME:
+        return QStringLiteral("UDS_MODIFICATION_TIME");
+    case UDSEntry::UDS_ACCESS_TIME:
+        return QStringLiteral("UDS_ACCESS_TIME");
+    case UDSEntry::UDS_CREATION_TIME:
+        return QStringLiteral("UDS_CREATION_TIME");
+    case UDSEntry::UDS_FILE_TYPE:
+        return QStringLiteral("UDS_FILE_TYPE");
+    case UDSEntry::UDS_LINK_DEST:
+        return QStringLiteral("UDS_LINK_DEST");
+    case UDSEntry::UDS_URL:
+        return QStringLiteral("UDS_URL");
+    case UDSEntry::UDS_MIME_TYPE:
+        return QStringLiteral("UDS_MIME_TYPE");
+    case UDSEntry::UDS_GUESSED_MIME_TYPE:
+        return QStringLiteral("UDS_GUESSED_MIME_TYPE");
+    case UDSEntry::UDS_XML_PROPERTIES:
+        return QStringLiteral("UDS_XML_PROPERTIES");
+    case UDSEntry::UDS_EXTENDED_ACL:
+        return QStringLiteral("UDS_EXTENDED_ACL");
+    case UDSEntry::UDS_ACL_STRING:
+        return QStringLiteral("UDS_ACL_STRING");
+    case UDSEntry::UDS_DEFAULT_ACL_STRING:
+        return QStringLiteral("UDS_DEFAULT_ACL_STRING");
+    case UDSEntry::UDS_DISPLAY_NAME:
+        return QStringLiteral("UDS_DISPLAY_NAME");
+    case UDSEntry::UDS_TARGET_URL:
+        return QStringLiteral("UDS_TARGET_URL");
+    case UDSEntry::UDS_DISPLAY_TYPE:
+        return QStringLiteral("UDS_DISPLAY_TYPE");
+    case UDSEntry::UDS_ICON_OVERLAY_NAMES:
+        return QStringLiteral("UDS_ICON_OVERLAY_NAMES");
+    case UDSEntry::UDS_COMMENT:
+        return QStringLiteral("UDS_COMMENT");
+    case UDSEntry::UDS_DEVICE_ID:
+        return QStringLiteral("UDS_DEVICE_ID");
+    case UDSEntry::UDS_INODE:
+        return QStringLiteral("UDS_INODE");
+    case UDSEntry::UDS_EXTRA:
+        return QStringLiteral("UDS_EXTRA");
+    case UDSEntry::UDS_EXTRA_END:
+        return QStringLiteral("UDS_EXTRA_END");
+    default:
+        return QStringLiteral("Unknown uds field %1").arg(field);
     }
 }
 
@@ -311,9 +334,9 @@ void UDSEntryPrivate::debugUDSEntry(QDebug &stream) const
     }
     stream << " ]";
 }
-//END UDSEntryPrivate
+// END UDSEntryPrivate
 
-//BEGIN UDSEntry
+// BEGIN UDSEntry
 /* ---------- UDSEntry ------------ */
 
 UDSEntry::UDSEntry()
@@ -330,25 +353,25 @@ UDSEntry::UDSEntry(const QT_STATBUF &buff, const QString &name)
 #else
     d->reserve(8);
 #endif
-    d->insert(UDS_NAME,                name);
-    d->insert(UDS_SIZE,                buff.st_size);
-    d->insert(UDS_DEVICE_ID,           buff.st_dev);
-    d->insert(UDS_INODE,               buff.st_ino);
-    d->insert(UDS_FILE_TYPE,           buff.st_mode & QT_STAT_MASK); // extract file type
-    d->insert(UDS_ACCESS,              buff.st_mode & 07777); // extract permissions
-    d->insert(UDS_MODIFICATION_TIME,   buff.st_mtime);
-    d->insert(UDS_ACCESS_TIME,         buff.st_atime);
+    d->insert(UDS_NAME, name);
+    d->insert(UDS_SIZE, buff.st_size);
+    d->insert(UDS_DEVICE_ID, buff.st_dev);
+    d->insert(UDS_INODE, buff.st_ino);
+    d->insert(UDS_FILE_TYPE, buff.st_mode & QT_STAT_MASK); // extract file type
+    d->insert(UDS_ACCESS, buff.st_mode & 07777); // extract permissions
+    d->insert(UDS_MODIFICATION_TIME, buff.st_mtime);
+    d->insert(UDS_ACCESS_TIME, buff.st_atime);
 #ifndef Q_OS_WIN
-    d->insert(UDS_USER,                KUser(buff.st_uid).loginName());
-    d->insert(UDS_GROUP,               KUserGroup(buff.st_gid).name());
+    d->insert(UDS_USER, KUser(buff.st_uid).loginName());
+    d->insert(UDS_GROUP, KUserGroup(buff.st_gid).name());
 #endif
 }
 
-UDSEntry::UDSEntry(const UDSEntry&) = default;
+UDSEntry::UDSEntry(const UDSEntry &) = default;
 UDSEntry::~UDSEntry() = default;
-UDSEntry::UDSEntry(UDSEntry&&) = default;
-UDSEntry& UDSEntry::operator=(const UDSEntry&) = default;
-UDSEntry& UDSEntry::operator=(UDSEntry&&) = default;
+UDSEntry::UDSEntry(UDSEntry &&) = default;
+UDSEntry &UDSEntry::operator=(const UDSEntry &) = default;
+UDSEntry &UDSEntry::operator=(UDSEntry &&) = default;
 
 QString UDSEntry::stringValue(uint field) const
 {
@@ -362,7 +385,7 @@ long long UDSEntry::numberValue(uint field, long long defaultValue) const
 
 bool UDSEntry::isDir() const
 {
-    return (numberValue(UDS_FILE_TYPE) & QT_STAT_MASK) == QT_STAT_DIR;
+    return Utils::isDirMask(numberValue(UDS_FILE_TYPE));
 }
 
 bool UDSEntry::isLink() const
@@ -435,7 +458,7 @@ void UDSEntry::clear()
 {
     d->clear();
 }
-//END UDSEntry
+// END UDSEntry
 
 KIOCORE_EXPORT QDebug operator<<(QDebug stream, const KIO::UDSEntry &entry)
 {
@@ -458,27 +481,27 @@ KIOCORE_EXPORT QDataStream &operator>>(QDataStream &s, KIO::UDSEntry &a)
 KIOCORE_EXPORT bool operator==(const KIO::UDSEntry &entry, const KIO::UDSEntry &other)
 {
     if (entry.count() != other.count()) {
-         return false;
-     }
+        return false;
+    }
 
-     const QVector<uint> fields = entry.fields();
-     for (uint field : fields) {
-         if (!other.contains(field)) {
-             return false;
-         }
+    const QVector<uint> fields = entry.fields();
+    for (uint field : fields) {
+        if (!other.contains(field)) {
+            return false;
+        }
 
-         if (field & UDSEntry::UDS_STRING) {
-             if (entry.stringValue(field) != other.stringValue(field)) {
-                 return false;
-             }
-         } else {
-             if (entry.numberValue(field) != other.numberValue(field)) {
-                 return false;
-             }
-         }
-     }
+        if (field & UDSEntry::UDS_STRING) {
+            if (entry.stringValue(field) != other.stringValue(field)) {
+                return false;
+            }
+        } else {
+            if (entry.numberValue(field) != other.numberValue(field)) {
+                return false;
+            }
+        }
+    }
 
-     return true;
+    return true;
 }
 
 KIOCORE_EXPORT bool operator!=(const KIO::UDSEntry &entry, const KIO::UDSEntry &other)
