@@ -26,10 +26,10 @@ public:
     enum MessageBoxDataType {
         MSG_TEXT,
         MSG_TITLE,
-        MSG_YES_BUTTON_TEXT,
-        MSG_NO_BUTTON_TEXT,
-        MSG_YES_BUTTON_ICON,
-        MSG_NO_BUTTON_ICON,
+        MSG_PRIMARYACTION_TEXT,
+        MSG_SECONDARYACTION_TEXT,
+        MSG_PRIMARYACTION_ICON,
+        MSG_SECONDARYACTION_ICON,
         MSG_DONT_ASK_AGAIN,
         MSG_DETAILS,
         MSG_META_DATA,
