@@ -11,41 +11,37 @@
 #include <KAboutData>
 #include <KConfig>
 #include <KIconButton>
-#include <KLineEdit>
+#include <KLineEdit> // For KUrlRequester::lineEdit()
 #include <KLocalizedString>
 #include <kio/global.h>
 #include <kprotocolinfo.h>
 #include <kurlrequester.h>
 
-#include <QDialogButtonBox>
-#include <QCheckBox>
-#include <qdrawutil.h>
-#include <QFormLayout>
 #include <QApplication>
+#include <QCheckBox>
+#include <QDialogButtonBox>
+#include <QFormLayout>
+#include <qdrawutil.h>
 
-#include <qplatformdefs.h>
 #include <KConfigGroup>
+#include <qplatformdefs.h>
 
-bool KFilePlaceEditDialog::getInformation(bool allowGlobal, QUrl &url,
-        QString &label, QString &icon,
-        bool isAddingNewPlace,
-        bool &appLocal, int iconSize,
-        QWidget *parent)
+bool KFilePlaceEditDialog::getInformation(bool allowGlobal,
+                                          QUrl &url,
+                                          QString &label,
+                                          QString &icon,
+                                          bool isAddingNewPlace,
+                                          bool &appLocal,
+                                          int iconSize,
+                                          QWidget *parent)
 {
-    KFilePlaceEditDialog *dialog = new KFilePlaceEditDialog(allowGlobal, url,
-            label, icon,
-            isAddingNewPlace,
-            appLocal,
-            iconSize,
-            parent);
+    KFilePlaceEditDialog *dialog = new KFilePlaceEditDialog(allowGlobal, url, label, icon, isAddingNewPlace, appLocal, iconSize, parent);
     if (dialog->exec() == QDialog::Accepted) {
         // set the return parameters
-        url         = dialog->url();
-        label       = dialog->label();
-        if (dialog->isIconEditable()) {
-            icon = dialog->icon();
-        }
-        appLocal    = dialog->applicationLocal();
+        url = dialog->url();
+        label = dialog->label();
+        icon = dialog->icon();
+        appLocal = dialog->applicationLocal();
 
         delete dialog;
         return true;
@@ -55,13 +51,16 @@ bool KFilePlaceEditDialog::getInformation(bool allowGlobal, QUrl &url,
     return false;
 }
 
-KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const QUrl &url,
-        const QString &label,
-        const QString &icon,
-        bool isAddingNewPlace,
-        bool appLocal, int iconSize,
-        QWidget *parent)
-    : QDialog(parent), m_iconButton(nullptr)
+KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal,
+                                           const QUrl &url,
+                                           const QString &label,
+                                           const QString &icon,
+                                           bool isAddingNewPlace,
+                                           bool appLocal,
+                                           int iconSize,
+                                           QWidget *parent)
+    : QDialog(parent)
+    , m_iconButton(nullptr)
 {
     if (isAddingNewPlace) {
         setWindowTitle(i18n("Add Places Entry"));
@@ -75,11 +74,12 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const QUrl &url,
     QFormLayout *layout = new QFormLayout();
     box->addLayout(layout);
 
-    QString whatsThisText = i18n("<qt>This is the text that will appear in the Places panel.<br /><br />"
-                                 "The label should consist of one or two words "
-                                 "that will help you remember what this entry refers to. "
-                                 "If you do not enter a label, it will be derived from "
-                                 "the location's URL.</qt>");
+    QString whatsThisText = i18n(
+        "<qt>This is the text that will appear in the Places panel.<br /><br />"
+        "The label should consist of one or two words "
+        "that will help you remember what this entry refers to. "
+        "If you do not enter a label, it will be derived from "
+        "the location's URL.</qt>");
     m_labelEdit = new QLineEdit(this);
     layout->addRow(i18n("L&abel:"), m_labelEdit);
     m_labelEdit->setText(label);
@@ -87,10 +87,12 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const QUrl &url,
     m_labelEdit->setWhatsThis(whatsThisText);
     layout->labelForField(m_labelEdit)->setWhatsThis(whatsThisText);
 
-    whatsThisText = i18n("<qt>This is the location associated with the entry. Any valid URL may be used. For example:<br /><br />"
-                         "%1<br />http://www.kde.org<br />ftp://ftp.kde.org/pub/kde/stable<br /><br />"
-                         "By clicking on the button next to the text edit box you can browse to an "
-                         "appropriate URL.</qt>", QDir::homePath());
+    whatsThisText = i18n(
+        "<qt>This is the location associated with the entry. Any valid URL may be used. For example:<br /><br />"
+        "%1<br />http://www.kde.org<br />ftp://ftp.kde.org/pub/kde/stable<br /><br />"
+        "By clicking on the button next to the text edit box you can browse to an "
+        "appropriate URL.</qt>",
+        QDir::homePath());
     m_urlEdit = new KUrlRequester(url, this);
     m_urlEdit->setMode(KFile::Directory);
     layout->addRow(i18n("&Location:"), m_urlEdit);
@@ -99,20 +101,29 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const QUrl &url,
     // Room for at least 40 chars (average char width is half of height)
     m_urlEdit->setMinimumWidth(m_urlEdit->fontMetrics().height() * (40 / 2));
 
-    if (isIconEditable()) {
-        whatsThisText = i18n("<qt>This is the icon that will appear in the Places panel.<br /><br />"
-                             "Click on the button to select a different icon.</qt>");
-        m_iconButton = new KIconButton(this);
+    whatsThisText = i18n(
+        "<qt>This is the icon that will appear in the Places panel.<br /><br />"
+        "Click on the button to select a different icon.</qt>");
+    m_iconButton = new KIconButton(this);
+    m_iconButton->setObjectName(QStringLiteral("icon button"));
+    m_iconButton->setIconSize(iconSize);
+    m_iconButton->setIconType(KIconLoader::NoGroup, KIconLoader::Place);
+    if (icon.isEmpty()) {
+        m_iconButton->setIcon(KIO::iconNameForUrl(url));
+    } else {
+        m_iconButton->setIcon(icon);
+    }
+    m_iconButton->setWhatsThis(whatsThisText);
+
+    if (url.scheme() == QLatin1String("trash")) {
+        // Since there are separate trash icons when it is empty/non-empty,
+        // the trash item's icon is made non-editable for simplicity
+        m_iconButton->hide();
+        // making the trash item's url editable misleads users into
+        // thinking that the actual trash location is configurable here
+        m_urlEdit->setDisabled(true);
+    } else {
         layout->addRow(i18n("Choose an &icon:"), m_iconButton);
-        m_iconButton->setObjectName(QStringLiteral("icon button"));
-        m_iconButton->setIconSize(iconSize);
-        m_iconButton->setIconType(KIconLoader::NoGroup, KIconLoader::Place);
-        if (icon.isEmpty()) {
-            m_iconButton->setIcon(KIO::iconNameForUrl(url));
-        } else {
-            m_iconButton->setIcon(icon);
-        }
-        m_iconButton->setWhatsThis(whatsThisText);
         layout->labelForField(m_iconButton)->setWhatsThis(whatsThisText);
     }
 
@@ -124,11 +135,12 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const QUrl &url,
         }
         m_appLocal = new QCheckBox(i18n("&Only show when using this application (%1)", appName), this);
         m_appLocal->setChecked(appLocal);
-        m_appLocal->setWhatsThis(i18n("<qt>Select this setting if you want this "
-                                      "entry to show only when using the current application (%1).<br /><br />"
-                                      "If this setting is not selected, the entry will be available in all "
-                                      "applications.</qt>",
-                                      appName));
+        m_appLocal->setWhatsThis(
+            i18n("<qt>Select this setting if you want this "
+                 "entry to show only when using the current application (%1).<br /><br />"
+                 "If this setting is not selected, the entry will be available in all "
+                 "applications.</qt>",
+                 appName));
         box->addWidget(m_appLocal);
     } else {
         m_appLocal = nullptr;
@@ -182,10 +194,6 @@ QString KFilePlaceEditDialog::label() const
 
 QString KFilePlaceEditDialog::icon() const
 {
-    if (!isIconEditable()) {
-        return QString();
-    }
-
     return m_iconButton->icon();
 }
 
@@ -198,7 +206,11 @@ bool KFilePlaceEditDialog::applicationLocal() const
     return m_appLocal->isChecked();
 }
 
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 86)
 bool KFilePlaceEditDialog::isIconEditable() const
 {
     return url().scheme() != QLatin1String("trash");
 }
+#endif
+
+#include "moc_kfileplaceeditdialog.cpp"
