@@ -1,44 +1,31 @@
-/*****************************************************************************
- * Copyright (C) 2006-2010 by Peter Penz <peter.penz@gmx.at>                 *
- * Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                     *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurlnavigatorbuttonbase_p.h"
 
 #include <KLocalizedString>
+#include <KUrlNavigator>
 
 #include <QStyle>
 #include <QStyleOptionViewItem>
 
 namespace KDEPrivate
 {
-
-KUrlNavigatorButtonBase::KUrlNavigatorButtonBase(QWidget *parent) :
-    QPushButton(parent),
-    m_active(true),
-    m_displayHint(0)
+KUrlNavigatorButtonBase::KUrlNavigatorButtonBase(KUrlNavigator *parent)
+    : QPushButton(parent)
+    , m_active(true)
+    , m_displayHint(0)
 {
     setFocusPolicy(Qt::TabFocus);
     setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
     setMinimumHeight(parent->minimumHeight());
     setAttribute(Qt::WA_LayoutUsesWidgetRect);
 
-    connect(this, SIGNAL(pressed()), parent, SLOT(requestActivation()));
+    connect(this, &KUrlNavigatorButtonBase::pressed, parent, &KUrlNavigator::requestActivation);
 }
 
 KUrlNavigatorButtonBase::~KUrlNavigatorButtonBase()
@@ -58,8 +45,7 @@ bool KUrlNavigatorButtonBase::isActive() const
     return m_active;
 }
 
-void KUrlNavigatorButtonBase::setDisplayHintEnabled(DisplayHint hint,
-        bool enable)
+void KUrlNavigatorButtonBase::setDisplayHintEnabled(DisplayHint hint, bool enable)
 {
     if (enable) {
         m_displayHint = m_displayHint | hint;
@@ -86,7 +72,11 @@ void KUrlNavigatorButtonBase::focusOutEvent(QFocusEvent *event)
     QPushButton::focusOutEvent(event);
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void KUrlNavigatorButtonBase::enterEvent(QEnterEvent *event)
+#else
 void KUrlNavigatorButtonBase::enterEvent(QEvent *event)
+#endif
 {
     QPushButton::enterEvent(event);
     setDisplayHintEnabled(EnteredHint, true);
@@ -102,9 +92,7 @@ void KUrlNavigatorButtonBase::leaveEvent(QEvent *event)
 
 void KUrlNavigatorButtonBase::drawHoverBackground(QPainter *painter)
 {
-    const bool isHighlighted = isDisplayHintEnabled(EnteredHint) ||
-                               isDisplayHintEnabled(DraggedHint) ||
-                               isDisplayHintEnabled(PopupActiveHint);
+    const bool isHighlighted = isDisplayHintEnabled(EnteredHint) || isDisplayHintEnabled(DraggedHint) || isDisplayHintEnabled(PopupActiveHint);
 
     QColor backgroundColor = isHighlighted ? palette().color(QPalette::Highlight) : Qt::transparent;
     if (!m_active && isHighlighted) {
@@ -123,9 +111,7 @@ void KUrlNavigatorButtonBase::drawHoverBackground(QPainter *painter)
 
 QColor KUrlNavigatorButtonBase::foregroundColor() const
 {
-    const bool isHighlighted = isDisplayHintEnabled(EnteredHint) ||
-                               isDisplayHintEnabled(DraggedHint) ||
-                               isDisplayHintEnabled(PopupActiveHint);
+    const bool isHighlighted = isDisplayHintEnabled(EnteredHint) || isDisplayHintEnabled(DraggedHint) || isDisplayHintEnabled(PopupActiveHint);
 
     QColor foregroundColor = palette().color(foregroundRole());
 
