@@ -84,7 +84,7 @@ QByteArray LegacyCodec::encodeFileNameUTF8(const QString &fileName)
 QString LegacyCodec::decodeFileNameUTF8(const QByteArray &localFileName)
 {
     const char *chars = localFileName.constData();
-    int len = qstrlen(chars);
+    const int len = localFileName.size();
     int need = 0;
     uint uc = 0;
     uint min_uc = 0;
@@ -151,7 +151,7 @@ error:
         if (ch < 128) {
             *qch++ = ushort(ch);
         } else {
-            uint uc = ch - 128 + 0x10FE00; //U+10FE00-U+10FE7F
+            uint uc = ch - 128 + 0x10FE00; // U+10FE00-U+10FE7F
             *qch++ = QChar::highSurrogate(uc);
             *qch++ = QChar::lowSurrogate(uc);
         }
