@@ -1,30 +1,18 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <KIO/EmptyTrashJob>
+#include <KLocalizedString>
+#include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QCoreApplication>
+#include <QDataStream>
 #include <QDebug>
 #include <QUrl>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
-#include <QDataStream>
-#include <KLocalizedString>
-#include <KIO/EmptyTrashJob>
 
 int main(int argc, char *argv[])
 {
@@ -36,11 +24,13 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.setApplicationDescription(i18n("Helper program to handle the KDE trash can\n"
-                                          "Note: to move files to the trash, do not use ktrash, but \"kioclient move 'url' trash:/\""));
+    parser.setApplicationDescription(
+        i18n("Helper program to handle the KDE trash can\n"
+             "Note: to move files to the trash, do not use ktrash, but \"kioclient move 'url' trash:/\""));
 
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("empty"), i18n("Empty the contents of the trash")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("restore"), i18n("Restore a trashed file to its original location"), QStringLiteral("file")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("empty")}, i18n("Empty the contents of the trash")));
+    parser.addOption(
+        QCommandLineOption(QStringList{QStringLiteral("restore")}, i18n("Restore a trashed file to its original location"), QStringLiteral("file")));
 
     parser.process(app);
 
@@ -54,7 +44,6 @@ int main(int argc, char *argv[])
 
     QString restoreArg = parser.value(QStringLiteral("restore"));
     if (!restoreArg.isEmpty()) {
-
         if (restoreArg.indexOf(QLatin1String("system:/trash")) == 0) {
             restoreArg.replace(0, 13, QStringLiteral("trash:"));
         }
