@@ -1,62 +1,46 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C)  2000-2005 David Faure <faure@kde.org>
-   Copyright (C)       2001 Waldo Bastian <bastian@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2000-2005 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-// TODO: remove me
-#undef QT_NO_CAST_FROM_ASCII
-
 #include "main.h"
 #include "kio_version.h"
 #include "kioexecdinterface.h"
 
-#include <QFile>
 #include <QDir>
-#include <Q_PID>
+#include <QFile>
 
-#include <job.h>
-#include <copyjob.h>
-#include <desktopexecparser.h>
+#include <KAboutData>
+#include <KDBusService>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KService>
 #include <QApplication>
 #include <QDebug>
-#include <KMessageBox>
-#include <KAboutData>
-#include <KRun>
-#include <KService>
-#include <KLocalizedString>
-#include <KDBusService>
+#include <copyjob.h>
+#include <desktopexecparser.h>
+#include <job.h>
 
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
+#include <QFileInfo>
 #include <QStandardPaths>
 #include <QThread>
-#include <QFileInfo>
 
 #include <KStartupInfo>
 #include <config-kioexec.h>
+
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
 #endif
-
-static const char description[] =
-    I18N_NOOP("KIO Exec - Opens remote files, watches modifications, asks for upload");
-
+#endif
 
 KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggestedFileName)
     : mExited(false)
@@ -75,7 +59,7 @@ KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggest
             KMessageBox::error(nullptr, i18n("Invalid URL: %1", args.value(i)));
             exit(1);
         }
-        KIO::StatJob* mostlocal = KIO::mostLocalUrl(urlArg);
+        KIO::StatJob *mostlocal = KIO::mostLocalUrl(urlArg);
         bool b = mostlocal->exec();
         if (!b) {
             KMessageBox::error(nullptr, i18n("File not found: %1", urlArg.toDisplayString()));
@@ -84,7 +68,7 @@ KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggest
         Q_ASSERT(b);
         const QUrl url = mostlocal->mostLocalUrl();
 
-        //kDebug() << "url=" << url.url() << " filename=" << url.fileName();
+        // kDebug() << "url=" << url.url() << " filename=" << url.fileName();
         // A local file, not an URL ?
         // => It is not encoded and not shell escaped, too.
         if (url.isLocalFile()) {
@@ -95,18 +79,23 @@ KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggest
         } else {
             // It is an URL
             if (!url.isValid()) {
-                KMessageBox::error(nullptr, i18n("The URL %1\nis malformed" ,  url.url()));
+                KMessageBox::error(nullptr, i18n("The URL %1\nis malformed", url.url()));
             } else if (mTempFiles) {
-                KMessageBox::error(nullptr, i18n("Remote URL %1\nnot allowed with --tempfiles switch" ,  url.toDisplayString()));
+                KMessageBox::error(nullptr, i18n("Remote URL %1\nnot allowed with --tempfiles switch", url.toDisplayString()));
             } else {
                 // We must fetch the file
                 QString fileName = KIO::encodeFileName(url.fileName());
-                if (!suggestedFileName.isEmpty())
+                if (!suggestedFileName.isEmpty()) {
                     fileName = suggestedFileName;
+                }
+                if (fileName.isEmpty()) {
+                    fileName = QStringLiteral("unnamed");
+                }
                 // Build the destination filename, in ~/.cache/kioexec/krun/
                 // Unlike KDE-1.1, we put the filename at the end so that the extension is kept
                 // (Some programs rely on it)
-                QString krun_writable = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/krun/%1_%2/").arg(QCoreApplication::applicationPid()).arg(jobCounter++);
+                QString krun_writable = QStandardPaths::writableLocation(QStandardPaths::CacheLocation)
+                    + QStringLiteral("/krun/%1_%2/").arg(QCoreApplication::applicationPid()).arg(jobCounter++);
                 QDir().mkpath(krun_writable); // error handling will be done by the job
                 QString tmp = krun_writable + fileName;
                 FileInfo file;
@@ -126,7 +115,8 @@ KIOExec::KIOExec(const QStringList &args, bool tempFiles, const QString &suggest
     }
 
     if (mTempFiles) {
-        slotRunApp();
+        // delay call so QApplication::exit passes the exit code to exec()
+        QTimer::singleShot(0, this, &KIOExec::slotRunApp);
         return;
     }
 
@@ -144,20 +134,20 @@ void KIOExec::slotResult(KJob *job)
 
         if (job->error()) {
             // That error dialog would be queued, i.e. not immediate...
-            //job->showErrorDialog();
-            if ((job->error() != KIO::ERR_USER_CANCELED))
+            // job->showErrorDialog();
+            if (job->error() != KIO::ERR_USER_CANCELED) {
                 KMessageBox::error(nullptr, job->errorString());
+            }
 
-            auto it = std::find_if(fileList.begin(), fileList.end(),
-                                   [&path](const FileInfo &i) { return (i.path == path); });
+            auto it = std::find_if(fileList.begin(), fileList.end(), [&path](const FileInfo &i) {
+                return i.path == path;
+            });
             if (it != fileList.end()) {
                 fileList.erase(it);
             } else {
-                qDebug() <<  path << " not found in list";
+                qDebug() << path << " not found in list";
             }
-        }
-        else
-        {
+        } else {
             // Tell kioexecd to watch the file for changes.
             const QString dest = copyJob->srcUrl().toString();
             qDebug() << "Telling kioexecd to watch path" << path << "dest" << dest;
@@ -198,8 +188,8 @@ void KIOExec::slotRunApp()
     list.reserve(fileList.size());
     // Store modification times
     QList<FileInfo>::Iterator it = fileList.begin();
-    for (; it != fileList.end() ; ++it) {
-        QFileInfo info(QFile::encodeName(it->path));
+    for (; it != fileList.end(); ++it) {
+        QFileInfo info(it->path);
         it->time = info.lastModified();
         QUrl url = QUrl::fromLocalFile(it->path);
         list << url;
@@ -207,8 +197,13 @@ void KIOExec::slotRunApp()
 
     KIO::DesktopExecParser execParser(service, list);
     QStringList params = execParser.resultingArguments();
+    if (params.isEmpty()) {
+        qWarning() << execParser.errorMessage();
+        QApplication::exit(-1);
+        return;
+    }
 
-    qDebug() << "EXEC " << params.join(QLatin1Char(' '));
+    qDebug() << "EXEC" << params.join(QLatin1Char(' '));
 
     // propagate the startup identification to the started process
     KStartupInfoId id;
@@ -236,17 +231,26 @@ void KIOExec::slotRunApp()
         const bool uploadChanges = !mUseDaemon && !dest.isLocalFile();
         if (info.exists() && (it->time != info.lastModified())) {
             if (mTempFiles) {
-                if (KMessageBox::questionYesNo(nullptr,
-                                               i18n("The supposedly temporary file\n%1\nhas been modified.\nDo you still want to delete it?", dest.toDisplayString(QUrl::PreferLocalFile)),
-                                               i18n("File Changed"), KStandardGuiItem::del(), KGuiItem(i18n("Do Not Delete"))) != KMessageBox::Yes)
+                const auto result = KMessageBox::questionTwoActions(
+                    nullptr,
+                    i18n("The supposedly temporary file\n%1\nhas been modified.\nDo you still want to delete it?", dest.toDisplayString(QUrl::PreferLocalFile)),
+                    i18n("File Changed"),
+                    KStandardGuiItem::del(),
+                    KGuiItem(i18n("Do Not Delete")));
+                if (result != KMessageBox::PrimaryAction) {
                     continue; // don't delete the temp file
+                }
             } else if (uploadChanges) { // no upload when it's already a local file or kioexecd already did it.
-                if (KMessageBox::questionYesNo(nullptr,
-                                               i18n("The file\n%1\nhas been modified.\nDo you want to upload the changes?" , dest.toDisplayString()),
-                                               i18n("File Changed"), KGuiItem(i18n("Upload")), KGuiItem(i18n("Do Not Upload"))) == KMessageBox::Yes) {
+                const auto result =
+                    KMessageBox::questionTwoActions(nullptr,
+                                                    i18n("The file\n%1\nhas been modified.\nDo you want to upload the changes?", dest.toDisplayString()),
+                                                    i18n("File Changed"),
+                                                    KGuiItem(i18n("Upload")),
+                                                    KGuiItem(i18n("Do Not Upload")));
+                if (result == KMessageBox::PrimaryAction) {
                     qDebug() << "src='" << src << "'  dest='" << dest << "'";
                     // Do it the synchronous way.
-                    KIO::CopyJob* job = KIO::copy(QUrl::fromLocalFile(src), dest);
+                    KIO::CopyJob *job = KIO::copy(QUrl::fromLocalFile(src), dest);
                     if (!job->exec()) {
                         KMessageBox::error(nullptr, job->errorText());
                         continue; // don't delete the temp file
@@ -255,14 +259,19 @@ void KIOExec::slotRunApp()
             }
         }
 
-        if ((uploadChanges || mTempFiles) && exit_code == 0) {            // Wait for a reasonable time so that even if the application forks on startup (like OOo or amarok)
+        if ((uploadChanges || mTempFiles) && exit_code == 0) {
+            // Wait for a reasonable time so that even if the application forks on startup (like OOo or amarok)
             // it will have time to start up and read the file before it gets deleted. #130709.
-            qDebug() << "sleeping...";
-            QThread::currentThread()->sleep(180); // 3 mn
+            const int sleepSecs = 180;
+            qDebug() << "sleeping for" << sleepSecs << "seconds before deleting file...";
+            QThread::sleep(sleepSecs);
             const QString parentDir = info.path();
-            qDebug() << "about to delete" << parentDir << "containing" << info.fileName();
-            QFile(QFile::encodeName(src)).remove();
-            QDir().rmdir(parentDir);
+            qDebug() << sleepSecs << "seconds have passed, deleting" << info.filePath();
+            QFile(src).remove();
+            // NOTE: this is not necessarily a temporary directory.
+            if (QDir().rmdir(parentDir)) {
+                qDebug() << "Removed empty parent directory" << parentDir;
+            }
         }
     }
 
@@ -273,8 +282,11 @@ void KIOExec::slotRunApp()
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("kioexec"), i18n("KIOExec"), QStringLiteral(KIO_VERSION_STRING),
-                         i18n(description), KAboutLicense::GPL,
+    KAboutData aboutData(QStringLiteral("kioexec"),
+                         i18n("KIOExec"),
+                         QStringLiteral(KIO_VERSION_STRING),
+                         i18n("KIO Exec - Opens remote files, watches modifications, asks for upload"),
+                         KAboutLicense::GPL,
                          i18n("(c) 1998-2000,2003 The KFM/Konqueror Developers"));
     aboutData.addAuthor(i18n("David Faure"), QString(), QStringLiteral("faure@kde.org"));
     aboutData.addAuthor(i18n("Stephan Kulow"), QString(), QStringLiteral("coolo@kde.org"));
@@ -285,8 +297,9 @@ int main(int argc, char **argv)
     KDBusService service(KDBusService::Multiple);
 
     QCommandLineParser parser;
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("tempfiles") , i18n("Treat URLs as local files and delete them afterwards")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("suggestedfilename"), i18n("Suggested file name for the downloaded file"), QStringLiteral("filename")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("tempfiles")}, i18n("Treat URLs as local files and delete them afterwards")));
+    parser.addOption(
+        QCommandLineOption(QStringList{QStringLiteral("suggestedfilename")}, i18n("Suggested file name for the downloaded file"), QStringLiteral("filename")));
     parser.addPositionalArgument(QStringLiteral("command"), i18n("Command to execute"));
     parser.addPositionalArgument(QStringLiteral("urls"), i18n("URL(s) or local file(s) used for 'command'"));
 
@@ -312,3 +325,5 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
+
+#include "moc_main.cpp"
