@@ -14,8 +14,8 @@
 
 #include <KCModule>
 
-#include "ui_ikwsopts_ui.h"
 #include "searchproviderregistry.h"
+#include "ui_ikwsopts_ui.h"
 
 class SearchProvider;
 class ProvidersModel;
@@ -25,7 +25,7 @@ class FilterOptions : public KCModule
     Q_OBJECT
 
 public:
-    explicit FilterOptions(QWidget *parent = nullptr);
+    explicit FilterOptions(QWidget *parent = nullptr, const QVariantList &args = {});
 
     void load() override;
     void save() override;
