@@ -72,7 +72,7 @@ public:
         return m_item;
     }
 
-    void setItem(const KFileItem &item)
+    virtual void setItem(const KFileItem &item)
     {
         m_item = item;
     }
@@ -115,7 +115,12 @@ public:
         : KDirModelNode(parent, item)
         , m_childCount(KDirModel::ChildCountUnknown)
         , m_populated(false)
+        , m_fsType(FsTypeUnknown)
     {
+        // If the parent node is on the network, all children are too. Opposite is not always true.
+        if (parent && parent->isOnNetwork()) {
+            m_fsType = NetworkFs;
+        }
     }
     ~KDirModelDirNode() override
     {
@@ -123,6 +128,16 @@ public:
     }
     QList<KDirModelNode *> m_childNodes; // owns the nodes
 
+    void setItem(const KFileItem &item) override
+    {
+        KDirModelNode::setItem(item);
+        if (item.isNull() || !item.url().isValid()) {
+            m_fsType = LocalFs;
+        } else {
+            m_fsType = FsTypeUnknown;
+        }
+    }
+
     // If we listed the directory, the child count is known. Otherwise it can be set via setChildCount.
     int childCount() const
     {
@@ -144,9 +159,12 @@ public:
         m_populated = populated;
     }
 
-    bool isSlow() const
+    bool isOnNetwork() const
     {
-        return item().isSlow();
+        if (!item().isNull() && m_fsType == FsTypeUnknown) {
+            m_fsType = item().isSlow() ? NetworkFs : LocalFs;
+        }
+        return m_fsType == NetworkFs;
     }
 
     // For removing all child urls from the global hash.
@@ -167,6 +185,8 @@ public:
 private:
     int m_childCount : 31;
     bool m_populated : 1;
+    // Network file system? (nfs/smb/ssh)
+    mutable enum { FsTypeUnknown, LocalFs, NetworkFs } m_fsType : 3;
 };
 
 int KDirModelNode::rowNumber() const
@@ -205,6 +225,7 @@ public:
         delete m_rootNode;
         m_rootNode = new KDirModelDirNode(nullptr, KFileItem());
         m_showNodeForListedUrl = false;
+        m_rootNode->setItem(KFileItem(m_dirLister->url()));
     }
 
     // Emit expand for each parent and then return the
@@ -748,12 +769,11 @@ void KDirModelPrivate::_k_slotClear()
     const int numRows = m_rootNode->m_childNodes.count();
     if (numRows > 0) {
         q->beginRemoveRows(QModelIndex(), 0, numRows - 1);
-        m_nodeHash.clear();
-        clear();
+    }
+    m_nodeHash.clear();
+    clear();
+    if (numRows > 0) {
         q->endRemoveRows();
-    } else {
-        m_nodeHash.clear();
-        clear();
     }
 }
 
@@ -873,7 +893,12 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
                     icon = QIcon::fromTheme(iconName, fallbackIcon);
                 }
 
-                return KIconUtils::addOverlays(icon, item.overlays());
+                const auto parentNode = node->parent();
+                if (parentNode->isOnNetwork()) {
+                    return icon;
+                } else {
+                    return KIconUtils::addOverlays(icon, item.overlays());
+                }
             }
             break;
         case Qt::TextAlignmentRole:
@@ -893,7 +918,7 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
             } else {
                 KDirModelDirNode *dirNode = static_cast<KDirModelDirNode *>(node);
                 int count = dirNode->childCount();
-                if (count == ChildCountUnknown && item.isReadable() && !dirNode->isSlow()) {
+                if (count == ChildCountUnknown && !dirNode->isOnNetwork() && item.isReadable()) {
                     const QString path = item.localPath();
                     if (!path.isEmpty()) {
 //                        slow
@@ -1238,7 +1263,7 @@ bool KDirModel::hasChildren(const QModelIndex &parent) const
     if (static_cast<const KDirModelDirNode *>(parentNode)->isPopulated()) {
         return !static_cast<const KDirModelDirNode *>(parentNode)->m_childNodes.isEmpty();
     }
-    if (parentItem.isLocalFile()) {
+    if (parentItem.isLocalFile() && !static_cast<const KDirModelDirNode *>(parentNode)->isOnNetwork()) {
         QDir::Filters filters = QDir::Dirs | QDir::NoDotAndDotDot;
 
         if (d->m_dirLister->dirOnlyMode()) {
