@@ -15,6 +15,8 @@
 #include <QString>
 #include <QUrl>
 
+#include <memory>
+
 class KService;
 class KJob;
 class QTimer;
@@ -35,9 +37,9 @@ class Job;
  * the default application or another application "bound" to the file type
  * (or URL protocol).
  *
- * In that example, the mimetype of the file is not known by the application,
- * so a KRun instance must be created. It will determine the mimetype by itself.
- * If the mimetype is known, or if you even know the service (application) to
+ * In that example, the MIME type of the file is not known by the application,
+ * so a KRun instance must be created. It will determine the MIME type by itself.
+ * If the MIME type is known, or if you even know the service (application) to
  * use for this file, use one of the static methods.
  *
  * By default KRun uses auto deletion. It causes the KRun instance to delete
@@ -73,23 +75,21 @@ public:
      *
      * @deprecated since 5.71, use KIO::OpenUrlJob(url) (except for KRun subclasses, for now)
      * @code
-     *   KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setStartupId(asn);
-     *   // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
-     *   // exist in both classes
-     *   job->start();
+     *    auto *job = new KIO::OpenUrlJob(url);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setStartupId(asn);
+     *    // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
+     *    // exist in both classes
+     *    job->start();
      * @endcode
      */
-    KRun(const QUrl &url, QWidget *window,
-         bool showProgressInfo = true,
-         const QByteArray &asn = QByteArray());
+    KRun(const QUrl &url, QWidget *window, bool showProgressInfo = true, const QByteArray &asn = QByteArray());
 
     /**
      * Destructor. Don't call it yourself, since a KRun object auto-deletes
      * itself.
      */
-    virtual ~KRun();
+    ~KRun() override;
 
     /**
      * Abort this KRun. This kills any jobs launched by it,
@@ -134,8 +134,8 @@ public:
 
     /**
      * Set the preferred service for opening this URL, after
-     * its mimetype will have been found by KRun. IMPORTANT: the service is
-     * only used if its configuration says it can handle this mimetype.
+     * its MIME type will have been found by KRun. IMPORTANT: the service is
+     * only used if its configuration says it can handle this MIME type.
      * This is used for instance for the X-KDE-LastOpenedWith key in
      * the recent documents list, or for the app selection in
      * KParts::BrowserOpenOrSaveQuestion.
@@ -170,7 +170,7 @@ public:
     /**
      * Sets the file name to use in the case of downloading the file to a tempfile
      * in order to give to a non-url-aware application. Some apps rely on the extension
-     * to determine the mimetype of the file. Usually the file name comes from the URL,
+     * to determine the MIME type of the file. Usually the file name comes from the URL,
      * but in the case of the HTTP Content-Disposition header, we need to override the
      * file name.
      */
@@ -185,7 +185,7 @@ public:
     void setShowScriptExecutionPrompt(bool showPrompt);
 
     /**
-     * Suggested file name given by the server (e.g. HTTP content-disposition)
+     * Suggested file name given by the server (e.g.\ HTTP content-disposition)
      */
     QString suggestedFileName() const;
 
@@ -211,20 +211,23 @@ public:
      *
      * @deprecated since 5.6. Since 5.71 use ApplicationLauncherJob, otherwise runApplication instead.
      * @code
-     *   KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
-     *   job->setUrls(urls);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   if (tempFiles) {
-     *       job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
-     *   }
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::ApplicationLauncherJob(service);
+     *    job->setUrls(urls);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    if (tempFiles) {
+     *        job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+     *    }
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 6, "Use KIO::ApplicationLauncherJob, see API docs for a code sample")
-    static bool run(const KService &service, const QList<QUrl> &urls, QWidget *window,
-                    bool tempFiles = false, const QString &suggestedFileName = QString(),
+    static bool run(const KService &service,
+                    const QList<QUrl> &urls,
+                    QWidget *window,
+                    bool tempFiles = false,
+                    const QString &suggestedFileName = QString(),
                     const QByteArray &asn = QByteArray());
 #endif
 
@@ -248,20 +251,23 @@ public:
      * @since 5.6
      * @deprecated since 5.71, use ApplicationLauncherJob instead.
      * @code
-     *   KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
-     *   job->setUrls(urls);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   if (tempFiles) {
-     *       job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
-     *   }
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::ApplicationLauncherJob(service);
+     *    job->setUrls(urls);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    if (tempFiles) {
+     *        job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+     *    }
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::ApplicationLauncherJob, see API docs for a code sample")
-    static qint64 runService(const KService &service, const QList<QUrl> &urls, QWidget *window,
-                             bool tempFiles = false, const QString &suggestedFileName = QString(),
+    static qint64 runService(const KService &service,
+                             const QList<QUrl> &urls,
+                             QWidget *window,
+                             bool tempFiles = false,
+                             const QString &suggestedFileName = QString(),
                              const QByteArray &asn = QByteArray());
 #endif
 
@@ -271,7 +277,7 @@ public:
      */
     enum RunFlag {
         DeleteTemporaryFiles = 0x1, ///< the URLs passed to the service will be deleted when it exits (if the URLs are local files)
-        RunExecutables = 0x2,       ///< Whether to run URLs that are executable scripts or binaries @see isExecutableFile() @since 5.31
+        RunExecutables = 0x2, ///< Whether to run URLs that are executable scripts or binaries @see isExecutableFile() @since 5.31
     };
     /**
      * Stores a combination of #RunFlag values.
@@ -282,7 +288,7 @@ public:
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
     /**
-     * Run an application (known from its .desktop file, i.e. as a KService)
+     * Run an application (known from its .desktop file, i.e.\ as a KService).
      *
      * If you need to wait for the application to register to D-Bus, use D-Bus activation instead.
      *
@@ -301,18 +307,21 @@ public:
      *
      * @deprecated since 5.71, use ApplicationLauncherJob instead.
      * @code
-     *   KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
-     *   job->setUrls(urls);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setRunFlags(flags);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::ApplicationLauncherJob(service);
+     *    job->setUrls(urls);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setRunFlags(flags);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::ApplicationLauncherJob, see API docs for a code sample")
-    static qint64 runApplication(const KService &service, const QList<QUrl> &urls, QWidget *window,
-                                 RunFlags flags = RunFlags(), const QString &suggestedFileName = QString(),
+    static qint64 runApplication(const KService &service,
+                                 const QList<QUrl> &urls,
+                                 QWidget *window,
+                                 RunFlags flags = RunFlags(),
+                                 const QString &suggestedFileName = QString(),
                                  const QByteArray &asn = QByteArray());
 #endif
 
@@ -335,16 +344,18 @@ public:
      *
      * @deprecated since 5.71, use KIO::ApplicationLauncherJob with a temporary KService
      * @code
-     *   KService::Ptr service(new KService(name, exec, icon));
-     *   KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
-     *   job->setUrls(urls);
-     *   job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    KService::Ptr service(new KService(name, exec, icon));
+     *    auto *job = new KIO::ApplicationLauncherJob(service);
+     *    job->setUrls(urls);
+     *    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::ApplicationLauncherJob with a temporary KService, see API docs for a code sample")
-    static bool run(const QString &exec, const QList<QUrl> &urls, QWidget *window,
+    static bool run(const QString &exec,
+                    const QList<QUrl> &urls,
+                    QWidget *window,
                     const QString &name = QString(),
                     const QString &icon = QString(),
                     const QByteArray &asn = QByteArray());
@@ -354,11 +365,11 @@ public:
     /**
      * Open the given URL.
      *
-     * This function is used after the mime type
+     * This function is used after the MIME type
      * is found out. It will search for all services which can handle
-     * the mime type and call run() afterwards.
+     * the MIME type and call run() afterwards.
      * @param url the URL to open
-     * @param mimetype the mime type of the resource
+     * @param mimetype the MIME type of the resource
      * @param window The top-level widget of the app that invoked this object.
      * @param tempFile if true and url is a local file, it will be deleted
      *        when the launched application exits.
@@ -370,30 +381,34 @@ public:
      * @return @c true on success, @c false on error
      * @deprecated since 5.31. Since 5.71 use OpenUrlJob, otherwise runUrl() with RunFlags.
      * @code
-     *   KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimetype);
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setRunExecutables(runExecutables);
-     *   job->setDeleteTemporaryFile(...); // depending on the old RunFlags
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::OpenUrlJob(url, mimetype);
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setRunExecutables(runExecutables);
+     *    job->setDeleteTemporaryFile(...); // depending on the old RunFlags
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 31, "Use KIO::OpenUrlJob, see API docs for a code sample")
-    static bool runUrl(const QUrl &url, const QString &mimetype, QWidget *window,
-                       bool tempFile = false, bool runExecutables = true,
-                       const QString &suggestedFileName = QString(), const QByteArray &asn = QByteArray());
+    static bool runUrl(const QUrl &url,
+                       const QString &mimetype,
+                       QWidget *window,
+                       bool tempFile = false,
+                       bool runExecutables = true,
+                       const QString &suggestedFileName = QString(),
+                       const QByteArray &asn = QByteArray());
 #endif
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
     /**
      * Open the given URL.
      *
-     * This function can be used after the mime type has been found out.
-     * It will search for all services which can handle the mime type and call run() afterwards.
+     * This function can be used after the MIME type has been found out.
+     * It will search for all services which can handle the MIME type and call run() afterwards.
      *
      * @param url The URL to open.
-     * @param mimetype The mime type of the resource.
+     * @param mimetype the MIME type of the resource
      * @param window The top-level widget of the app that invoked this object.
      * @param flags Various run flags.
      * @param suggestedFileName See setSuggestedFileName()
@@ -402,18 +417,22 @@ public:
      * @since 5.31
      * @deprecated since 5.71, use KIO::OpenUrlJob:
      * @code
-     *   KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimetype);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setRunExecutables(runExecutables);
-     *   job->setDeleteTemporaryFile(...); // depending on the old RunFlags
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::OpenUrlJob(url, mimetype);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setRunExecutables(runExecutables);
+     *    job->setDeleteTemporaryFile(...); // depending on the old RunFlags
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::OpenUrlJob, see API docs for a code sample")
-    static bool runUrl(const QUrl &url, const QString &mimetype, QWidget *window, RunFlags flags,
-                       const QString &suggestedFileName = QString(), const QByteArray &asn = QByteArray());
+    static bool runUrl(const QUrl &url,
+                       const QString &mimetype,
+                       QWidget *window,
+                       RunFlags flags,
+                       const QString &suggestedFileName = QString(),
+                       const QByteArray &asn = QByteArray());
 #endif
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
@@ -434,10 +453,10 @@ public:
      * @return @c true on success, @c false on error
      * @deprecated since 5.71, use KIO::CommandLauncherJob
      * @code
-     *   KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(cmd);
-     *   job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setWorkingDirectory(workingDirectory);
-     *   job->start();
+     *    auto *job = new KIO::CommandLauncherJob(cmd);
+     *    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setWorkingDirectory(workingDirectory);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::CommandLauncherJob, see API docs for a code sample")
@@ -458,18 +477,17 @@ public:
      * @return @c true on success, @c false on error
      * @deprecated since 5.71, use KIO::CommandLauncherJob
      * @code
-     *   KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(cmd);
-     *   job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setWorkingDirectory(workingDirectory);
-     *   job->setExecutable(execName);
-     *   job->setIcon(icon);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::CommandLauncherJob(cmd);
+     *    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setWorkingDirectory(workingDirectory);
+     *    job->setExecutable(execName);
+     *    job->setIcon(icon);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::CommandLauncherJob, see API docs for a code sample")
-    static bool runCommand(const QString &cmd, const QString &execName,
-                           const QString &icon, QWidget *window, const QByteArray &asn = QByteArray());
+    static bool runCommand(const QString &cmd, const QString &execName, const QString &icon, QWidget *window, const QByteArray &asn = QByteArray());
 #endif
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
@@ -481,19 +499,18 @@ public:
      * @since 4.4
      * @deprecated since 5.71, use KIO::CommandLauncherJob instead
      * @code
-     *   KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(cmd);
-     *   job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   job->setWorkingDirectory(workingDirectory);
-     *   job->setExecutable(execName);
-     *   job->setIcon(icon);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::CommandLauncherJob(cmd);
+     *    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    job->setWorkingDirectory(workingDirectory);
+     *    job->setExecutable(execName);
+     *    job->setIcon(icon);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::CommandLauncherJob, see API docs for a code sample")
-    static bool runCommand(const QString &cmd, const QString &execName,
-                           const QString &icon, QWidget *window,
-                           const QByteArray &asn, const QString &workingDirectory);
+    static bool
+    runCommand(const QString &cmd, const QString &execName, const QString &icon, QWidget *window, const QByteArray &asn, const QString &workingDirectory);
 #endif
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
@@ -508,20 +525,22 @@ public:
      * @return false if the dialog was canceled
      * @deprecated since 5.71, use KIO::ApplicationLauncherJob with no service argument (or a null service)
      * @code
-     *   KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob();
-     *   job->setUrls(urls);
-     *   job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-     *   if (tempFiles) {
-     *       job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
-     *   }
-     *   job->setSuggestedFileName(suggestedFileName);
-     *   job->setStartupId(asn);
-     *   job->start();
+     *    auto *job = new KIO::ApplicationLauncherJob();
+     *    job->setUrls(urls);
+     *    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+     *    if (tempFiles) {
+     *        job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+     *    }
+     *    job->setSuggestedFileName(suggestedFileName);
+     *    job->setStartupId(asn);
+     *    job->start();
      * @endcode
      */
-    KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::OpenUrlJob, see API docs for a code sample")
-    static bool displayOpenWithDialog(const QList<QUrl> &lst, QWidget *window,
-                                      bool tempFiles = false, const QString &suggestedFileName = QString(),
+    KIOWIDGETS_DEPRECATED_VERSION(5, 71, "Use KIO::ApplicationLauncherJob, see API docs for a code sample")
+    static bool displayOpenWithDialog(const QList<QUrl> &lst,
+                                      QWidget *window,
+                                      bool tempFiles = false,
+                                      const QString &suggestedFileName = QString(),
                                       const QByteArray &asn = QByteArray());
 #endif
 
@@ -553,14 +572,13 @@ public:
      * @deprecated since 5.0, use KIO::DesktopExecParser
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KIO::DesktopExecParser")
-    static QStringList processDesktopExec(const KService &_service, const QList<QUrl> &_urls,
-            bool tempFiles = false,
-            const QString &suggestedFileName = QString());
+    static QStringList
+    processDesktopExec(const KService &_service, const QList<QUrl> &_urls, bool tempFiles = false, const QString &suggestedFileName = QString());
 #endif
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * Given a full command line (e.g. the Exec= line from a .desktop file),
+     * Given a full command line (e.g.\ the Exec= line from a .desktop file),
      * extract the name of the binary being run.
      * @param execLine the full command line
      * @param removePath if true, remove a (relative or absolute) path. E.g. /usr/bin/ls becomes ls.
@@ -583,20 +601,19 @@ public:
      * To be executable the file must pass the following rules:
      * -# Must reside on the local filesystem.
      * -# Must be marked as executable for the user by the filesystem.
-     * -# The mime type must inherit application/x-executable, application/x-executable-script or application/x-sharedlib.
+     * -# The MIME type must inherit application/x-executable, application/x-executable-script or application/x-sharedlib.
      * To allow a script to run when the above rules are satisfied add the entry
      * @code
      * X-KDE-IsAlso=application/x-executable-script
      * @endcode
-     * to the mimetype's desktop file.
+     * to the MIME type's desktop file.
      */
     static bool isExecutableFile(const QUrl &url, const QString &mimetype);
 
     /**
      * @internal
      */
-    static bool checkStartupNotify(const QString &binName, const KService *service, bool *silent_arg,
-                                   QByteArray *wmclass_arg);
+    static bool checkStartupNotify(const QString &binName, const KService *service, bool *silent_arg, QByteArray *wmclass_arg);
 
 Q_SIGNALS:
     /**
@@ -629,12 +646,12 @@ protected Q_SLOTS:
 
     /**
      * This slot is called when the scan job has found out
-     * the mime type.
+     * the MIME type.
      */
     void slotScanMimeType(KIO::Job *, const QString &type);
 
     /**
-     * Call this from subclasses when you have determined the mimetype.
+     * Call this from subclasses when you have determined the MIME type.
      * It will call foundMimeType, but also sets up protection against deletion during message boxes.
      * @since 4.0.2
      */
@@ -661,8 +678,8 @@ protected:
     virtual void scanFile();
 
     /**
-     * Called if the mimetype has been detected. The function runs
-     * the application associated with this mimetype.
+     * Called if the MIME type has been detected. The function runs
+     * the application associated with this MIME type.
      * Reimplement this method to implement a different behavior,
      * like opening the component for displaying the URL embedded.
      *
@@ -798,7 +815,7 @@ protected:
 
 private:
     friend class KRunPrivate;
-    KRunPrivate *const d;
+    std::unique_ptr<KRunPrivate> const d;
 };
 #endif
 
