@@ -1,41 +1,27 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KRUN_P_H
 #define KRUN_P_H
 
-#include <memory>
+#include <QEventLoopLocker>
 #include <QObject>
 #include <QPointer>
 #include <QTimer>
-#include <QEventLoopLocker>
-#include <QProcess>
-#include <KService>
+#include <memory>
 class KProcess;
 
 #include "executablefileopendialog_p.h"
-#include "kstartupinfo.h"
 
-namespace KIO {
-    class ApplicationLauncherJob;
-    class CommandLauncherJob;
+namespace KIO
+{
+class ApplicationLauncherJob;
+class CommandLauncherJob;
 }
 
 /**
@@ -46,16 +32,14 @@ class Q_DECL_HIDDEN KRunPrivate
 public:
     KRunPrivate(KRun *parent);
 
-    void init(const QUrl &url, QWidget *window,
-              bool showProgressInfo, const QByteArray &asn);
+    void init(const QUrl &url, QWidget *window, bool showProgressInfo, const QByteArray &asn);
 
     // This helper method makes debugging easier: a single breakpoint for all
     // the code paths that start the timer - at least from KRun itself.
     void startTimer();
 
 #ifdef Q_OS_WIN
-    static bool displayNativeOpenWithDialog(const QList<QUrl> &lst, QWidget *window, bool tempFiles,
-                                            const QString &suggestedFileName, const QByteArray &asn);
+    static bool displayNativeOpenWithDialog(const QList<QUrl> &lst, QWidget *window, bool tempFiles, const QString &suggestedFileName, const QByteArray &asn);
 #endif
     bool runExternalBrowser(const QString &_exec);
     static qint64 runCommandLauncherJob(KIO::CommandLauncherJob *job, QWidget *widget);
@@ -68,7 +52,7 @@ public:
     ExecutableFileOpenDialog::Mode promptMode();
     void onDialogFinished(int result, bool isDontAskAgainSet);
 
-    KRun * const q;
+    KRun *const q;
     bool m_showingDialog;
     bool m_runExecutables;
     bool m_followRedirections;
@@ -80,7 +64,7 @@ public:
     QString m_externalBrowser;
     QString m_localPath;
     QString m_suggestedFileName;
-    QPointer <QWidget> m_window;
+    QPointer<QWidget> m_window;
     QByteArray m_asn;
     QUrl m_strURL;
     bool m_bFault;
@@ -113,4 +97,4 @@ public:
     bool m_externalBrowserEnabled;
 };
 
-#endif  // KRUN_P_H
+#endif // KRUN_P_H
