@@ -14,6 +14,7 @@
 #include <KService>
 #include <kio/global.h>
 
+#include <KPluginFactory>
 #include <KPluginMetaData>
 
 #include <QHashIterator>
@@ -672,3 +673,5 @@ void KUriFilter::loadPlugins()
         }
     }
 }
+
+#include "moc_kurifilter.cpp"
