@@ -10,8 +10,7 @@
 #include <kio/global.h> // iconNameForUrl
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 75)
-QPixmap KIO::pixmapForUrl(const QUrl &url, int mode, KIconLoader::Group group,
-                          int force_size, int state, QString *path)
+QPixmap KIO::pixmapForUrl(const QUrl &url, int mode, KIconLoader::Group group, int force_size, int state, QString *path)
 {
     Q_UNUSED(mode);
     const QString iconName = KIO::iconNameForUrl(url);
