@@ -1,16 +1,14 @@
 /*
- *
- * This file is part of the KDE project.
- * Copyright (C) 2001 Carsten Pfeiffer <pfeiffer@kde.org>
- *
- * You can Freely distribute this program under the GNU Library General Public
- * License. See the file "COPYING" for the exact licensing terms.
- */
+    This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-#include <qapplication.h>
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
+
+#include <QApplication>
+#include <QDebug>
 #include <kurlrequester.h>
 #include <kurlrequesterdialog.h>
-#include <QDebug>
 
 int main(int argc, char **argv)
 {
@@ -29,5 +27,14 @@ int main(int argc, char **argv)
     req1->setWindowTitle(QStringLiteral("AAAAAAAAAAAA"));
     req1->show();
 
+    KUrlComboRequester *comboReq = new KUrlComboRequester();
+    comboReq->setWindowTitle(QStringLiteral("KUrlComboRequester"));
+    comboReq->show();
+
+    auto *mimeFilterReq = new KUrlRequester();
+    mimeFilterReq->setMimeTypeFilters({QStringLiteral("text/x-c++src")});
+    mimeFilterReq->setWindowTitle(QStringLiteral("MimeFilter"));
+    mimeFilterReq->show();
+
     return app.exec();
 }
