@@ -1,12 +1,13 @@
 #ifndef PREVIEWTEST_H
 #define PREVIEWTEST_H
 
-#include <qwidget.h>
-#include <kio/job.h>
+#include <QWidget>
 
 class QLineEdit;
 class QLabel;
+
 class KFileItem;
+class KJob;
 
 class PreviewTest : public QWidget
 {
@@ -27,4 +28,3 @@ private:
 };
 
 #endif
-
